@@ -1,14 +1,15 @@
 #include "Bdef.h"
 
 #if (INTFACE == C_CALL)
-void Cblacs_abort(int ConTxt, int ErrNo)
+void Cblacs_abort(Int ConTxt, Int ErrNo)
 #else
-F_VOID_FUNC blacs_abort_(int *ConTxt, int *ErrNo)
+F_VOID_FUNC blacs_abort_(Int *ConTxt, Int *ErrNo)
 #endif
 {
-   void BI_BlacsAbort(int ErrNo);
-   int nprow, npcol, myrow, mycol;
-   extern int BI_Iam;
+   void Cblacs_gridinfo(Int, Int *, Int *, Int *, Int *);
+   void BI_BlacsAbort(Int ErrNo);
+   Int nprow, npcol, myrow, mycol;
+   extern Int BI_Iam;
 
    Cblacs_gridinfo(Mpval(ConTxt), &nprow, &npcol, &myrow, &mycol);
    fprintf(stderr,
