@@ -1,9 +1,9 @@
 #include "Bdef.h"
 
 #if (INTFACE == C_CALL)
-int Ckrecvid(int ConTxt, int rsrc, int csrc)
+Int Ckrecvid(Int ConTxt, Int rsrc, Int csrc)
 #else
-F_INT_FUNC krecvid_(int *ConTxt, int *rsrc, int *csrc)
+F_INT_FUNC krecvid_(Int *ConTxt, Int *rsrc, Int *csrc)
 #endif
 {
    return(PT2PTID+1);
