@@ -1,12 +1,12 @@
 #include "Bdef.h"
 
 #if (INTFACE == C_CALL)
-void Cztrbr2d(int ConTxt, char *scope, char *top, char *uplo, char *diag,
-              int m, int n, double *A, int lda, int rsrc, int csrc)
+void Cztrbr2d(Int ConTxt, char *scope, char *top, char *uplo, char *diag,
+              Int m, Int n, double *A, Int lda, Int rsrc, Int csrc)
 #else
-F_VOID_FUNC ztrbr2d_(int *ConTxt, F_CHAR scope, F_CHAR top, F_CHAR uplo,
-                     F_CHAR diag, int *m, int *n, double *A, int *lda,
-                     int *rsrc, int *csrc)
+F_VOID_FUNC ztrbr2d_(Int *ConTxt, F_CHAR scope, F_CHAR top, F_CHAR uplo,
+                     F_CHAR diag, Int *m, Int *n, double *A, Int *lda,
+                     Int *rsrc, Int *csrc)
 #endif
 /*
  *  -- V1.1 BLACS routine --
@@ -20,7 +20,7 @@ F_VOID_FUNC ztrbr2d_(int *ConTxt, F_CHAR scope, F_CHAR top, F_CHAR uplo,
  *  Arguments
  *  =========
  *
- *  ConTxt  (input) Ptr to int
+ *  ConTxt  (input) Ptr to Int
  *          Index into MyConTxts00 (my contexts array).
  *
  *  SCOPE   (input) Ptr to char
@@ -42,10 +42,10 @@ F_VOID_FUNC ztrbr2d_(int *ConTxt, F_CHAR scope, F_CHAR top, F_CHAR uplo,
  *          = 'U':      Matrix is unit diagonal, diagonal not communicated.
  *          ELSE :      Matrix is not unit diagonal, diagonal is communicated.
  *
- *  M       (input) Ptr to int
+ *  M       (input) Ptr to Int
  *          The number of rows of the matrix A.  M >= 0.
  *
- *  N       (input) Ptr to int
+ *  N       (input) Ptr to Int
  *          The number of columns of the matrix A.  N >= 0.
  *
  *  A       (output) Ptr to double complex two dimensional array
@@ -54,41 +54,41 @@ F_VOID_FUNC ztrbr2d_(int *ConTxt, F_CHAR scope, F_CHAR top, F_CHAR uplo,
  *          If UPLO = 'U', only the upper trapezoid is accessed;
  *          if UPLO = 'L', only the lower trapezoid is accessed.
  *
- *  LDA     (input) Ptr to int
+ *  LDA     (input) Ptr to Int
  *          The leading dimension of the array A.  LDA >= M.
  *
  *
- *  RSRC    (input) Ptr to int
+ *  RSRC    (input) Ptr to Int
  *          The process row of the source of the matrix.
  *
- *  CSRC    (input) Ptr to int
+ *  CSRC    (input) Ptr to Int
  *          The process column of the source of the matrix.
  *
  *
  * ------------------------------------------------------------------------
  */
 {
-   void BI_ArgCheck(int, int, char *, char, char, char, int, int, int, int,
-                    int *, int *);
-   int BI_HypBR(BLACSCONTEXT *, BLACBUFF *, SDRVPTR, int);
-   void BI_IdringBR(BLACSCONTEXT *, BLACBUFF *, SDRVPTR, int, int);
-   void BI_SringBR(BLACSCONTEXT *, BLACBUFF *, SDRVPTR, int);
-   void BI_MpathBR(BLACSCONTEXT *, BLACBUFF *, SDRVPTR, int, int);
-   void BI_TreeBR(BLACSCONTEXT *, BLACBUFF *, SDRVPTR, int, int);
+   void BI_ArgCheck(Int, Int, char *, char, char, char, Int, Int, Int, Int,
+                    Int *, Int *);
+   Int BI_HypBR(BLACSCONTEXT *, BLACBUFF *, SDRVPTR, Int);
+   void BI_IdringBR(BLACSCONTEXT *, BLACBUFF *, SDRVPTR, Int, Int);
+   void BI_SringBR(BLACSCONTEXT *, BLACBUFF *, SDRVPTR, Int);
+   void BI_MpathBR(BLACSCONTEXT *, BLACBUFF *, SDRVPTR, Int, Int);
+   void BI_TreeBR(BLACSCONTEXT *, BLACBUFF *, SDRVPTR, Int, Int);
    void BI_UpdateBuffs(BLACBUFF *);
-   BLACBUFF *BI_GetBuff(int);
-   int BI_BuffIsFree(BLACBUFF *, int);
-   MPI_Datatype BI_GetMpiTrType(BLACSCONTEXT *, char, char, int, int, int,
-                                   MPI_Datatype, int *);
+   BLACBUFF *BI_GetBuff(Int);
+   Int BI_BuffIsFree(BLACBUFF *, Int);
+   MPI_Datatype BI_GetMpiTrType(BLACSCONTEXT *, char, char, Int, Int, Int,
+                                   MPI_Datatype, Int *);
    void BI_Unpack(BLACSCONTEXT *, BVOID *, BLACBUFF *, MPI_Datatype);
-   void BI_Ssend(BLACSCONTEXT *, int, int, BLACBUFF *);
-   void BI_Asend(BLACSCONTEXT *, int, int, BLACBUFF *);
+   void BI_Ssend(BLACSCONTEXT *, Int, Int, BLACBUFF *);
+   void BI_Asend(BLACSCONTEXT *, Int, Int, BLACBUFF *);
 
    BLACSCONTEXT *ctxt;
    BLACBUFF *bp=NULL;
    SDRVPTR send;
    MPI_Datatype MatTyp;
-   int length, src, tlda, error, one=1;
+   Int length, src, tlda, error, one=1;
    char ttop, tscope, tuplo, tdiag;
    extern BLACBUFF BI_AuxBuff, *BI_ActiveQ;
 
