@@ -17,10 +17,10 @@
 #include "../PBblas.h"
 
 #ifdef __STDC__
-void PB_CInOutV2( PBTYP_T * TYPE, char * CONJUG, char * ROWCOL, int M,
-                  int N, int KA, int * DESCA, int K, char * Y, int IY,
-                  int JY, int * DESCY, char * YROC, char * * YAPTR,
-                  int * DYA, int * YAFREE, int * YASUM, int * YAPBY )
+void PB_CInOutV2( PBTYP_T * TYPE, char * CONJUG, char * ROWCOL, Int M,
+                  Int N, Int KA, Int * DESCA, Int K, char * Y, Int IY,
+                  Int JY, Int * DESCY, char * YROC, char * * YAPTR,
+                  Int * DYA, Int * YAFREE, Int * YASUM, Int * YAPBY )
 #else
 void PB_CInOutV2( TYPE, CONJUG, ROWCOL, M, N, KA, DESCA, K, Y, IY, JY,
                   DESCY, YROC, YAPTR, DYA, YAFREE, YASUM, YAPBY )
@@ -28,12 +28,12 @@ void PB_CInOutV2( TYPE, CONJUG, ROWCOL, M, N, KA, DESCA, K, Y, IY, JY,
 *  .. Scalar Arguments ..
 */
    char           * CONJUG, * ROWCOL, * YROC;
-   int            * YAPBY, * YAFREE, IY, JY, K, KA, M, N, * YASUM;
+   Int            * YAPBY, * YAFREE, IY, JY, K, KA, M, N, * YASUM;
    PBTYP_T        * TYPE;
 /*
 *  .. Array Arguments ..
 */
-   int            * DESCA, * DESCY, * DYA;
+   Int            * DESCA, * DESCY, * DYA;
    char           * Y, * * YAPTR;
 #endif
 {
@@ -226,7 +226,7 @@ void PB_CInOutV2( TYPE, CONJUG, ROWCOL, M, N, KA, DESCA, K, Y, IY, JY,
 /*
 *  .. Local Scalars ..
 */
-   int            Acol, Acoldst, Aimb, Ainb, AisD, AisR, Amb, Amp, Anb, Anq,
+   Int            Acol, Acoldst, Aimb, Ainb, AisD, AisR, Amb, Amp, Anb, Anq,
                   Arow, Arowdst, Ycol, Yii, Yimb, Yimb1, Yinb, Yinb1, YisD,
                   YisR, YisRow, Yjj, Yld, Ymb, Ymp, Ynb, Ynq, Yrow, ctxt,
                   izero=0, nprow, myrow, npcol, mycol;
