@@ -17,21 +17,21 @@
 #include "PBblas.h"
 
 #ifdef __STDC__
-void pcher_( F_CHAR_T UPLO, int * N, float * ALPHA,
-             float * X, int * IX, int * JX, int * DESCX, int * INCX,
-             float * A, int * IA, int * JA, int * DESCA )
+void pcher_( F_CHAR_T UPLO, Int * N, float * ALPHA,
+             float * X, Int * IX, Int * JX, Int * DESCX, Int * INCX,
+             float * A, Int * IA, Int * JA, Int * DESCA )
 #else
 void pcher_( UPLO, N, ALPHA, X, IX, JX, DESCX, INCX, A, IA, JA, DESCA )
 /*
 *  .. Scalar Arguments ..
 */
    F_CHAR_T       UPLO;
-   int            * IA, * INCX, * IX, * JA, * JX, * N;
+   Int            * IA, * INCX, * IX, * JA, * JX, * N;
    float          * ALPHA;
 /*
 *  .. Array Arguments ..
 */
-   int            * DESCA, * DESCX;
+   Int            * DESCA, * DESCX;
    float          * A, * X;
 #endif
 {
@@ -214,7 +214,7 @@ void pcher_( UPLO, N, ALPHA, X, IX, JX, DESCX, INCX, A, IA, JA, DESCA )
 *  .. Local Scalars ..
 */
    char           UploA;
-   int            Acol, Ai, Aii, Aimb1, Ainb1, Aj, Ajj, Akp, Akq, Ald, Amb,
+   Int            Acol, Ai, Aii, Aimb1, Ainb1, Aj, Ajj, Akp, Akq, Ald, Amb,
                   Amp, Amp0, Anb, Anq, Anq0, Arow, XCfr, XCld, XRfr, XRld,
                   Xi, Xj, ctxt, info, ione=1, k, kb, ktmp, mycol, myrow, nb,
                   npcol, nprow, size, upper;
@@ -223,7 +223,7 @@ void pcher_( UPLO, N, ALPHA, X, IX, JX, DESCX, INCX, A, IA, JA, DESCA )
 /*
 *  .. Local Arrays ..
 */
-   int            Ad[DLEN_], Ad0[DLEN_], XCd0[DLEN_], XRd0[DLEN_], Xd[DLEN_];
+   Int            Ad[DLEN_], Ad0[DLEN_], XCd0[DLEN_], XRd0[DLEN_], Xd[DLEN_];
    char           * Aptr = NULL, * XC = NULL, * XR = NULL;
 /* ..
 *  .. Executable Statements ..
