@@ -17,19 +17,19 @@
 #include "PBblas.h"
 
 #ifdef __STDC__
-void psamax_( int * N, float * AMAX, int * INDX,
-              float * X, int * IX, int * JX, int * DESCX, int * INCX )
+void psamax_( Int * N, float * AMAX, Int * INDX,
+              float * X, Int * IX, Int * JX, Int * DESCX, Int * INCX )
 #else
 void psamax_( N, AMAX, INDX, X, IX, JX, DESCX, INCX )
 /*
 *  .. Scalar Arguments ..
 */
-   int            * INCX, * INDX, * IX, * JX, * N;
+   Int            * INCX, * INDX, * IX, * JX, * N;
    float          * AMAX;
 /*
 *  .. Array Arguments ..
 */
-   int            * DESCX;
+   Int            * DESCX;
    float          * X;
 #endif
 {
@@ -181,13 +181,13 @@ void psamax_( N, AMAX, INDX, X, IX, JX, DESCX, INCX )
 *  .. Local Scalars ..
 */
    char           cbtop, cctop, rbtop, rctop;
-   int            Xcol, Xgindx, Xi, Xii, Ximb, Xinb, Xj, Xjj, Xlindx, Xld, Xmb,
+   Int            Xcol, Xgindx, Xi, Xii, Ximb, Xinb, Xj, Xjj, Xlindx, Xld, Xmb,
                   Xnb, Xnp, Xnq, Xrow, Xsrc, ctxt, dist, dst, idumm, info, k,
                   maxpos, mycol, mydist, myrow, npcol, nprow, src;
 /*
 *  .. Local Arrays ..
 */
-   int            Xd[DLEN_];
+   Int            Xd[DLEN_];
    float          work[4];
 /* ..
 *  .. Executable Statements ..
@@ -260,7 +260,7 @@ void psamax_( N, AMAX, INDX, X, IX, JX, DESCX, INCX )
             {
                Xld = Xd[LLD_];
                Xlindx = Xjj - 1 +
-                        isamax_( &Xnq, ((char*)(X+(Xii+Xjj*Xld))), &Xld );
+                        isamax_( &Xnq, ((char*)(Mptr(X,Xii,Xjj,Xld,1))), &Xld );
                Mindxl2g( Xgindx, Xlindx, Xinb, Xnb, mycol, Xsrc, npcol );
                work[0] = X[Xii+Xlindx*Xld];
                work[1] = ((float )( Xgindx+1 ));
@@ -324,7 +324,7 @@ l_20:
 *  zero, then select a coherent INDX.
 */
             *AMAX = work[0];
-            *INDX = ( ( *AMAX == ZERO ) ? ( *JX ) : ( (int)(work[1]) ) );
+            *INDX = ( ( *AMAX == ZERO ) ? ( *JX ) : ( (Int)(work[1]) ) );
          }
          else
          {
@@ -343,8 +343,8 @@ l_20:
 */
                Xld = Xd[LLD_];
                Xlindx = Xjj - 1 +
-                        isamax_( &Xnq, ((char*)(X+(Xii+Xjj*Xld))), &Xld );
-               *AMAX = X[Xii+Xlindx*Xld];
+                        isamax_( &Xnq, ((char*)(Mptr(X,Xii,Xjj,Xld, 1))), &Xld );
+               *AMAX = *Mptr(X,Xii,Xlindx,Xld,1);
             }
             else
             {
@@ -419,9 +419,9 @@ l_20:
             {
                Xld     = Xd[LLD_];
                Xlindx  = Xii - 1 +
-                         isamax_( &Xnp, ((char*)(X+(Xii+Xjj*Xld))), INCX );
+                         isamax_( &Xnp, ((char*)Mptr(X,Xii,Xjj,Xld,1)), INCX );
                Mindxl2g( Xgindx, Xlindx, Ximb, Xmb, myrow, Xsrc, nprow );
-               work[0] = X[Xlindx+Xjj*Xld];
+               work[0] = *Mptr(X,Xlindx,Xjj,Xld,1);
                work[1] = ((float )( Xgindx+1 ));
             }
             else
@@ -483,7 +483,7 @@ l_40:
 *  zero, then select a coherent INDX.
 */
             *AMAX = work[0];
-            *INDX = ( ( *AMAX == ZERO ) ? ( *IX ) : ( (int)(work[1]) ) );
+            *INDX = ( ( *AMAX == ZERO ) ? ( *IX ) : ( (Int)(work[1]) ) );
          }
          else
          {
