@@ -17,19 +17,19 @@
 #include "PBblas.h"
 
 #ifdef __STDC__
-void pscopy_( int * N,
-              float * X, int * IX, int * JX, int * DESCX, int * INCX,
-              float * Y, int * IY, int * JY, int * DESCY, int * INCY )
+void pscopy_( Int * N,
+              float * X, Int * IX, Int * JX, Int * DESCX, Int * INCX,
+              float * Y, Int * IY, Int * JY, Int * DESCY, Int * INCY )
 #else
 void pscopy_( N, X, IX, JX, DESCX, INCX, Y, IY, JY, DESCY, INCY )
 /*
 *  .. Scalar Arguments ..
 */
-   int            * INCX, * INCY, * IX, * IY, * JX, * JY, * N;
+   Int            * INCX, * INCY, * IX, * IY, * JX, * JY, * N;
 /*
 *  .. Array Arguments ..
 */
-   int            * DESCX, * DESCY;
+   Int            * DESCX, * DESCY;
    float          * X, * Y;
 #endif
 {
@@ -177,12 +177,12 @@ void pscopy_( N, X, IX, JX, DESCX, INCX, Y, IY, JY, DESCY, INCY )
 /*
 *  .. Local Scalars ..
 */
-   int            Xi, Xj, Yi, Yj, ctxt, info, mycol, myrow, npcol, nprow;
+   Int            Xi, Xj, Yi, Yj, ctxt, info, mycol, myrow, npcol, nprow;
    PBTYP_T        * type;
 /*
 *  .. Local Arrays ..
 */
-   int            Xd[DLEN_], Yd[DLEN_];
+   Int            Xd[DLEN_], Yd[DLEN_];
 /* ..
 *  .. Executable Statements ..
 *
