@@ -1,9 +1,18 @@
+      BLOCK DATA
+      INTEGER NSUBS
+      PARAMETER (NSUBS = 7)
+      CHARACTER*7        SNAMES( NSUBS )
+      COMMON             /SNAMEC/SNAMES
+      DATA               SNAMES/'PDGEMV ', 'PDSYMV ', 'PDTRMV ',
+     $                   'PDTRSV ', 'PDGER  ', 'PDSYR  ',
+     $                   'PDSYR2 '/
+      END BLOCK DATA      
+
       PROGRAM PDBLA2TIM
 *
-*  -- PBLAS timing driver (version 2.0) --
-*     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
-*     and University of California, Berkeley.
-*     April 1, 1998
+*  -- PBLAS timing driver (version 2.0.2) --
+*     Univ. of Tennessee, Univ. of California Berkeley, Univ. of Colorado Denver
+*     May 1 2012
 *
 *  Purpose
 *  =======
@@ -183,9 +192,6 @@
       COMMON             /PBERRORC/NOUT, ABRTFLG
 *     ..
 *     .. Data Statements ..
-      DATA               SNAMES/'PDGEMV ', 'PDSYMV ', 'PDTRMV ',
-     $                   'PDTRSV ', 'PDGER  ', 'PDSYR  ',
-     $                   'PDSYR2 '/
       DATA               YCHECK/.TRUE., .TRUE., .FALSE., .FALSE.,
      $                   .TRUE., .FALSE., .TRUE./
 *     ..
