@@ -1,9 +1,18 @@
+      BLOCK DATA
+      INTEGER NSUBS
+      PARAMETER (NSUBS = 8)
+      CHARACTER*7        SNAMES( NSUBS )
+      COMMON             /SNAMEC/SNAMES
+      DATA               SNAMES/'PDGEMM ', 'PDSYMM ', 'PDSYRK ',
+     $                   'PDSYR2K', 'PDTRMM ', 'PDTRSM ',
+     $                   'PDGEADD', 'PDTRADD'/
+      END BLOCK DATA
+
       PROGRAM PDBLA3TIM
 *
-*  -- PBLAS timing driver (version 2.0) --
-*     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
-*     and University of California, Berkeley.
-*     April 1, 1998
+*  -- PBLAS timing driver (version 2.0.2) --
+*     Univ. of Tennessee, Univ. of California Berkeley, Univ. of Colorado Denver
+*     May 1 2012
 *
 *  Purpose
 *  =======
@@ -187,9 +196,6 @@
       COMMON             /PBERRORC/NOUT, ABRTFLG
 *     ..
 *     .. Data Statements ..
-      DATA               SNAMES/'PDGEMM ', 'PDSYMM ', 'PDSYRK ',
-     $                   'PDSYR2K', 'PDTRMM ', 'PDTRSM ',
-     $                   'PDGEADD', 'PDTRADD'/
       DATA               BCHECK/.TRUE., .TRUE., .FALSE., .TRUE., .TRUE.,
      $                   .TRUE., .FALSE., .FALSE./
       DATA               CCHECK/.TRUE., .TRUE., .TRUE., .TRUE., .FALSE.,
