@@ -1,9 +1,18 @@
+      BLOCK DATA
+      INTEGER NSUBS
+      PARAMETER (NSUBS = 8)
+      CHARACTER*7        SNAMES( NSUBS )
+      COMMON             /SNAMEC/SNAMES
+      DATA               SNAMES/'PSSWAP ', 'PSSCAL ', 'PSCOPY ',
+     $                   'PSAXPY ', 'PSDOT  ', 'PSNRM2 ',
+     $                   'PSASUM ', 'PSAMAX '/
+      END BLOCK DATA
+
       PROGRAM PSBLA1TIM
 *
-*  -- PBLAS timing driver (version 2.0) --
-*     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
-*     and University of California, Berkeley.
-*     April 1, 1998
+*  -- PBLAS timing driver (version 2.0.2) --
+*     Univ. of Tennessee, Univ. of California Berkeley, Univ. of Colorado Denver
+*     May 1 2012
 *
 *  Purpose
 *  =======
@@ -151,9 +160,6 @@
       COMMON             /PBERRORC/NOUT, ABRTFLG
 *     ..
 *     .. Data Statements ..
-      DATA               SNAMES/'PSSWAP ', 'PSSCAL ', 'PSCOPY ',
-     $                   'PSAXPY ', 'PSDOT  ', 'PSNRM2 ',
-     $                   'PSASUM ', 'PSAMAX '/
       DATA               YCHECK/.TRUE., .FALSE., .TRUE., .TRUE., .TRUE.,
      $                   .FALSE., .FALSE., .FALSE./
 *     ..
