@@ -1,9 +1,19 @@
+      BLOCK DATA
+      INTEGER NSUBS
+      PARAMETER (NSUBS = 10)
+      CHARACTER*7        SNAMES( NSUBS )
+      COMMON             /SNAMEC/SNAMES
+      DATA               SNAMES/'PZSWAP ', 'PZSCAL ',
+     $                   'PZDSCAL', 'PZCOPY', 'PZAXPY ',
+     $                   'PZDOTU ', 'PZDOTC' , 'PDZNRM2',
+     $                   'PDZASUM', 'PZAMAX '/
+      END BLOCK DATA
+
       PROGRAM PZBLA1TIM
 *
-*  -- PBLAS timing driver (version 2.0) --
-*     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
-*     and University of California, Berkeley.
-*     April 1, 1998
+*  -- PBLAS timing driver (version 2.0.2) --
+*     Univ. of Tennessee, Univ. of California Berkeley, Univ. of Colorado Denver
+*     May 1 2012
 *
 *  Purpose
 *  =======
@@ -156,10 +166,6 @@
       COMMON             /PBERRORC/NOUT, ABRTFLG
 *     ..
 *     .. Data Statements ..
-      DATA               SNAMES/'PZSWAP ', 'PZSCAL ',
-     $                   'PZDSCAL ', 'PZCOPY', 'PZAXPY ',
-     $                   'PZDOTU ', 'PZDOTC' , 'PDZNRM2',
-     $                   'PDZASUM', 'PZAMAX '/
       DATA               YCHECK/.TRUE., .FALSE., .FALSE., .TRUE.,
      $                   .TRUE., .TRUE., .TRUE., .FALSE., .FALSE.,
      $                   .FALSE./
