@@ -1,9 +1,19 @@
+      BLOCK DATA
+      INTEGER NSUBS
+      PARAMETER (NSUBS = 11)
+      CHARACTER*7        SNAMES( NSUBS )
+      COMMON             /SNAMEC/SNAMES
+      DATA               SNAMES/'PZGEMM ', 'PZSYMM ', 'PZHEMM ',
+     $                   'PZSYRK ', 'PZHERK ', 'PZSYR2K',
+     $                   'PZHER2K', 'PZTRMM ', 'PZTRSM ',
+     $                   'PZGEADD', 'PZTRADD'/
+      END BLOCK DATA
+      
       PROGRAM PZBLA3TIM
 *
-*  -- PBLAS timing driver (version 2.0) --
-*     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
-*     and University of California, Berkeley.
-*     April 1, 1998
+*  -- PBLAS timing driver (version 2.0.2) --
+*     Univ. of Tennessee, Univ. of California Berkeley, Univ. of Colorado Denver
+*     May 1 2012
 *
 *  Purpose
 *  =======
@@ -195,10 +205,6 @@
       COMMON             /PBERRORC/NOUT, ABRTFLG
 *     ..
 *     .. Data Statements ..
-      DATA               SNAMES/'PZGEMM ', 'PZSYMM ', 'PZHEMM ',
-     $                   'PZSYRK ', 'PZHERK ', 'PZSYR2K',
-     $                   'PZHER2K', 'PZTRMM ', 'PZTRSM ',
-     $                   'PZGEADD', 'PZTRADD'/
       DATA               BCHECK/.TRUE., .TRUE., .TRUE., .FALSE.,
      $                   .FALSE., .TRUE., .TRUE., .TRUE., .TRUE.,
      $                   .FALSE., .FALSE./
