@@ -104,11 +104,12 @@ extern void Cpigemr2d();
 #include <stdio.h>
 #include <stdlib.h>
 #include <assert.h>
+const size_t NEGFLAG = ~( ((size_t)-1) >> 1);
 void *
-mr2d_malloc(Int n)
+mr2d_malloc(size_t n)
 {
   void *ptr;
-  assert(n > 0);
+  assert((n & NEGFLAG) == 0);
   ptr = (void *) malloc(n);
   if (ptr == NULL) {
     fprintf(stderr, "xxmr2d:out of memory\n");
@@ -157,14 +158,14 @@ localsize(Int myprow, Int p, Int nbrow, Int m)
 	blockheight = (m / templateheight) * nbrow + nbrow;
       } else {	/* processor (myprow,mypcol)'s part is not complete */
 	blockheight = (m / templateheight) * nbrow + (m % nbrow);
-      };	/* if ((m%templateheight) > (nbrow*(myprow+1))) */
+      }	/* if ((m%templateheight) > (nbrow*(myprow+1))) */
     } else {	/* processor (myprow,mypcol) has no element in that
 		 * incomplete template */
       blockheight = (m / templateheight) * nbrow;
-    };	/* if ((m%templateheight) > (nbrow*myprow)) */
+    }	/* if ((m%templateheight) > (nbrow*myprow)) */
   } else {	/* exact boundary */
     blockheight = m / p;	/* (m/templateheight) * nbrow */
-  };	/* if (m%templateheight !=0) */
+  }	/* if (m%templateheight !=0) */
   return blockheight;
 }
 /****************************************************************/
