@@ -3,10 +3,10 @@
 *
 *
 *
-*  -- ScaLAPACK routine (version 1.6) --
+*  -- ScaLAPACK routine (version 1.7) --
 *     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
 *     and University of California, Berkeley.
-*     November 15, 1997
+*     August 7, 2001
 *
 *     .. Scalar Arguments ..
       CHARACTER          TRANS
@@ -375,7 +375,7 @@
 *
 *  Code Developer: Andrew J. Cleary, University of Tennessee.
 *    Current address: Lawrence Livermore National Labs.
-*  This version released: May, 1997.
+*  This version released: August, 2001.
 *
 *  =====================================================================
 *
@@ -411,7 +411,7 @@
 *     ..
 *     .. External Subroutines ..
       EXTERNAL           BLACS_GRIDINFO, DESC_CONVERT, GLOBCHK,
-     $                   PCDTTRSV, PXERBLA
+     $                   PCDTTRSV, PXERBLA, RESHAPE
 *     ..
 *     .. External Functions ..
       LOGICAL            LSAME
