@@ -1,12 +1,9 @@
       SUBROUTINE PCDTTRSV( UPLO, TRANS, N, NRHS, DL, D, DU, JA, DESCA,
      $                     B, IB, DESCB, AF, LAF, WORK, LWORK, INFO )
 *
-*
-*
-*  -- ScaLAPACK routine (version 1.7) --
-*     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
-*     and University of California, Berkeley.
-*     November 15, 1997
+*  -- ScaLAPACK routine (version 2.0.2) --
+*     Univ. of Tennessee, Univ. of California Berkeley, Univ. of Colorado Denver
+*     May 1 2012
 *
 *     .. Scalar Arguments ..
       CHARACTER          TRANS, UPLO
@@ -417,7 +414,7 @@
 *     ..
 *     .. External Subroutines ..
       EXTERNAL           BLACS_GET, BLACS_GRIDEXIT, BLACS_GRIDINFO,
-     $                   CGEMM, CGERV2D, CGESD2D, CLACPY, CMATADD,
+     $                   CGEMM, CGERV2D, CGESD2D, CLAMOV, CMATADD,
      $                   CTBTRS, CTRMM, CTRTRS, DESC_CONVERT, GLOBCHK,
      $                   PXERBLA, RESHAPE
 *     ..
