@@ -1,12 +1,9 @@
       SUBROUTINE PCPBTRSV( UPLO, TRANS, N, BW, NRHS, A, JA, DESCA, B,
      $                     IB, DESCB, AF, LAF, WORK, LWORK, INFO )
 *
-*
-*
-*  -- ScaLAPACK routine (version 1.7) --
-*     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
-*     and University of California, Berkeley.
-*     November 15, 1997
+*  -- ScaLAPACK routine (version 2.0.2) --
+*     Univ. of Tennessee, Univ. of California Berkeley, Univ. of Colorado Denver
+*     May 1 2012
 *
 *     .. Scalar Arguments ..
       CHARACTER          TRANS, UPLO
@@ -400,7 +397,7 @@
 *     ..
 *     .. External Subroutines ..
       EXTERNAL           BLACS_GET, BLACS_GRIDEXIT, BLACS_GRIDINFO,
-     $                   CGEMM, CGERV2D, CGESD2D, CLACPY, CMATADD,
+     $                   CGEMM, CGERV2D, CGESD2D, CLAMOV, CMATADD,
      $                   CTBTRS, CTRMM, CTRTRS, DESC_CONVERT, GLOBCHK,
      $                   PXERBLA, RESHAPE
 *     ..
@@ -772,7 +769,7 @@
 *           First copy and multiply it into temporary storage,
 *             then use it on RHS
 *
-            CALL CLACPY( 'N', BW, NRHS,
+            CALL CLAMOV( 'N', BW, NRHS,
      $                B( PART_OFFSET+ODD_SIZE-BW+1), LLDB,
      $                WORK( 1 ), BW )
 *
@@ -1115,7 +1112,7 @@
 *         First copy and multiply it into temporary storage,
 *           then use it on RHS
 *
-          CALL CLACPY( 'N', BW, NRHS, B( PART_OFFSET+ODD_SIZE+1), LLDB,
+          CALL CLAMOV( 'N', BW, NRHS, B( PART_OFFSET+ODD_SIZE+1), LLDB,
      $                 WORK( 1+BW-BW ), BW )
 *
           CALL CTRMM( 'L', 'U', 'C', 'N', BW, NRHS, -CONE,
@@ -1168,7 +1165,7 @@
 *           First copy and multiply it into temporary storage,
 *             then use it on RHS
 *
-            CALL CLACPY( 'N', BW, NRHS,
+            CALL CLAMOV( 'N', BW, NRHS,
      $                B( PART_OFFSET+ODD_SIZE-BW+1), LLDB,
      $                WORK( 1 ), BW )
 *
@@ -1511,7 +1508,7 @@
 *         First copy and multiply it into temporary storage,
 *           then use it on RHS
 *
-          CALL CLACPY( 'N', BW, NRHS, B( PART_OFFSET+ODD_SIZE+1), LLDB,
+          CALL CLAMOV( 'N', BW, NRHS, B( PART_OFFSET+ODD_SIZE+1), LLDB,
      $                 WORK( 1+BW-BW ), BW )
 *
           CALL CTRMM( 'L', 'L', 'N', 'N', BW, NRHS, -CONE,
