@@ -1,10 +1,10 @@
       SUBROUTINE PCUNM2R( SIDE, TRANS, M, N, K, A, IA, JA, DESCA, TAU,
      $                    C, IC, JC, DESCC, WORK, LWORK, INFO )
 *
-*  -- ScaLAPACK routine (version 1.5) --
+*  -- ScaLAPACK routine (version 1.7) --
 *     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
 *     and University of California, Berkeley.
-*     May 1, 1997
+*     May 25, 2001
 *
 *     .. Scalar Arguments ..
       CHARACTER          SIDE, TRANS
@@ -227,7 +227,7 @@
       EXTERNAL           BLACS_ABORT, BLACS_GRIDINFO, CGEBR2D,
      $                   CGEBS2D, CGERV2D, CGESD2D, CHK1MAT,
      $                   CSCAL, INFOG2L, PCELSET, PCELSET2,
-     $                   PCLARF, PCLARFC, PTOPGET, PTOPSET, PXERBLA
+     $                   PCLARF, PCLARFC, PB_TOPGET, PB_TOPSET, PXERBLA
 *     ..
 *     .. External Functions ..
       LOGICAL            LSAME
@@ -379,8 +379,8 @@
 *
       ELSE
 *
-         CALL PTOPGET( ICTXT, 'Broadcast', 'Rowwise', ROWBTOP )
-         CALL PTOPGET( ICTXT, 'Broadcast', 'Columnwise', COLBTOP )
+         CALL PB_TOPGET( ICTXT, 'Broadcast', 'Rowwise', ROWBTOP )
+         CALL PB_TOPGET( ICTXT, 'Broadcast', 'Columnwise', COLBTOP )
 *
          IF( LEFT .AND. .NOT.NOTRAN .OR. .NOT.LEFT .AND. NOTRAN ) THEN
             J1 = JA
@@ -396,11 +396,11 @@
             NI  = N
             JCC = JC
             IF( NOTRAN ) THEN
-               CALL PTOPSET( ICTXT, 'Broadcast', 'Rowwise', 'D-ring' )
+               CALL PB_TOPSET( ICTXT, 'Broadcast', 'Rowwise', 'D-ring' )
             ELSE
-               CALL PTOPSET( ICTXT, 'Broadcast', 'Rowwise', 'I-ring' )
+               CALL PB_TOPSET( ICTXT, 'Broadcast', 'Rowwise', 'I-ring' )
             END IF
-            CALL PTOPSET( ICTXT, 'Broadcast', 'Columnwise', ' ' )
+            CALL PB_TOPSET( ICTXT, 'Broadcast', 'Columnwise', ' ' )
          ELSE
             MI  = M
             ICC = IC
@@ -435,8 +435,8 @@
 *
    10    CONTINUE
 *
-         CALL PTOPSET( ICTXT, 'Broadcast', 'Rowwise', ROWBTOP )
-         CALL PTOPSET( ICTXT, 'Broadcast', 'Columnwise', COLBTOP )
+         CALL PB_TOPSET( ICTXT, 'Broadcast', 'Rowwise', ROWBTOP )
+         CALL PB_TOPSET( ICTXT, 'Broadcast', 'Columnwise', COLBTOP )
 *
       END IF
 *
