@@ -14,12 +14,13 @@
  * Include Files
  */
 #include "pxsyevx.h"
+#include "pblas.h"
 #include <stdio.h>
 #include <math.h>
 #define  proto(x)	()
 
 
-void pdlasnbt_( int *ieflag )
+void pdlasnbt_( Int *ieflag )
 {
 /* 
 *
@@ -55,8 +56,8 @@ void pdlasnbt_( int *ieflag )
 *  .. Local Scalars ..
 */
    double x;
-   int         negone=-1, errornum;
-   unsigned int *ix; 
+   Int         negone=-1, errornum;
+   unsigned Int *ix; 
 /* ..
 *  .. Executable Statements ..
 */
@@ -64,12 +65,12 @@ void pdlasnbt_( int *ieflag )
 #ifdef NO_IEEE
    *ieflag = 0;
 #else
-   if(sizeof(int) != 4){
+   if(sizeof(Int) != 4){
       *ieflag = 0;
       return;
    }
    x = (double) -1.0;
-   ix = (unsigned int *) &x;
+   ix = (unsigned Int *) &x;
    if(( *ix == 0xbff00000) && ( *(ix+1) == 0x0) ) 
    {
       *ieflag = 1;
@@ -81,7 +82,7 @@ void pdlasnbt_( int *ieflag )
 #endif
 }
 
-void pdlaiectb_( double *sigma, int *n, double *d, int *count )
+void pdlaiectb_( double *sigma, Int *n, double *d, Int *count )
 {
 /* 
 *
@@ -131,7 +132,7 @@ void pdlaiectb_( double *sigma, int *n, double *d, int *count )
 *  .. Local Scalars ..
 */
    double      lsigma, tmp, *pd, *pe2;
-   int         i;
+   Int         i;
 /* ..
 *  .. Executable Statements ..
 */
@@ -139,15 +140,15 @@ void pdlaiectb_( double *sigma, int *n, double *d, int *count )
    lsigma = *sigma;
    pd = d; pe2 = d+1;
    tmp = *pd - lsigma; pd += 2;
-   *count = (*((int *)&tmp) >> 31) & 1;
+   *count = (*((Int *)&tmp) >> 31) & 1;
    for(i = 1;i < *n;i++){
       tmp = *pd - *pe2/tmp - lsigma;
       pd += 2; pe2 += 2;
-      *count += ((*((int *)&tmp)) >> 31) & 1;
+      *count += ((*((Int *)&tmp)) >> 31) & 1;
    }
 }
 
-void pdlaiectl_( double *sigma, int *n, double *d, int *count )
+void pdlaiectl_( double *sigma, Int *n, double *d, Int *count )
 {
 /* 
 *
@@ -197,7 +198,7 @@ void pdlaiectl_( double *sigma, int *n, double *d, int *count )
 *  .. Local Scalars ..
 */
    double      lsigma, tmp, *pd, *pe2;
-   int         i;
+   Int         i;
 /* ..
 *  .. Executable Statements ..
 */
@@ -205,15 +206,15 @@ void pdlaiectl_( double *sigma, int *n, double *d, int *count )
    lsigma = *sigma;
    pd = d; pe2 = d+1;
    tmp = *pd - lsigma; pd += 2;
-   *count = (*(((int *)&tmp)+1) >> 31) & 1;
+   *count = (*(((Int *)&tmp)+1) >> 31) & 1;
    for(i = 1;i < *n;i++){
       tmp = *pd - *pe2/tmp - lsigma;
       pd += 2; pe2 += 2;
-      *count += (*(((int *)&tmp)+1) >> 31) & 1;
+      *count += (*(((Int *)&tmp)+1) >> 31) & 1;
    }
 }
 
-void pdlachkieee_( int *isieee, double *rmax, double *rmin )
+void pdlachkieee_( Int *isieee, double *rmax, double *rmin )
 {
 /* 
 *
@@ -250,7 +251,7 @@ void pdlachkieee_( int *isieee, double *rmax, double *rmin )
 *  .. Local Scalars ..
 */
    double x, pinf, pzero, ninf, nzero;
-   int         ieflag, *ix, sbit1, sbit2, negone=-1, errornum;
+   Int         ieflag, *ix, sbit1, sbit2, negone=-1, errornum;
 /* ..
 *  .. Executable Statements ..
 */
@@ -267,11 +268,11 @@ void pdlachkieee_( int *isieee, double *rmax, double *rmin )
       return ;
    }
    if( ieflag == 1 ){
-      sbit1 = (*((int *)&pzero) >> 31) & 1;
-      sbit2 = (*((int *)&pinf) >> 31) & 1;
+      sbit1 = (*((Int *)&pzero) >> 31) & 1;
+      sbit2 = (*((Int *)&pinf) >> 31) & 1;
    }else if(ieflag == 2){
-      sbit1 = (*(((int *)&pzero)+1) >> 31) & 1;
-      sbit2 = (*(((int *)&pinf)+1) >> 31) & 1;
+      sbit1 = (*(((Int *)&pzero)+1) >> 31) & 1;
+      sbit2 = (*(((Int *)&pinf)+1) >> 31) & 1;
    }
    if( sbit1 == 1 ){
       printf("Sign of positive infinity is incorrect\n");
@@ -291,11 +292,11 @@ void pdlachkieee_( int *isieee, double *rmax, double *rmin )
       *isieee = 0;
    }
    if( ieflag == 1 ){
-      sbit1 = (*((int *)&nzero) >> 31) & 1;
-      sbit2 = (*((int *)&ninf) >> 31) & 1;
+      sbit1 = (*((Int *)&nzero) >> 31) & 1;
+      sbit2 = (*((Int *)&ninf) >> 31) & 1;
    }else if(ieflag == 2){
-      sbit1 = (*(((int *)&nzero)+1) >> 31) & 1;
-      sbit2 = (*(((int *)&ninf)+1) >> 31) & 1;
+      sbit1 = (*(((Int *)&nzero)+1) >> 31) & 1;
+      sbit2 = (*(((Int *)&ninf)+1) >> 31) & 1;
    }
    if( sbit1 == 0 ){
       printf("Sign of negative infinity is incorrect\n");
