@@ -1,10 +1,9 @@
       SUBROUTINE PDSYTTRD( UPLO, N, A, IA, JA, DESCA, D, E, TAU, WORK,
      $                     LWORK, INFO )
 *
-*  -- ScaLAPACK routine (version 1.7) --
-*     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
-*     and University of California, Berkeley.
-*     May 25, 2001
+*  -- ScaLAPACK routine (version 2.0.2) --
+*     Univ. of Tennessee, Univ. of California Berkeley, Univ. of Colorado Denver
+*     May 1 2012
 *
 *     .. Scalar Arguments ..
       CHARACTER          UPLO
@@ -442,7 +441,7 @@
 *     .. External Subroutines ..
       EXTERNAL           BLACS_GRIDINFO, CHK1MAT, DCOMBNRM2, DGEBR2D,
      $                   DGEBS2D, DGEMM, DGEMV, DGERV2D, DGESD2D,
-     $                   DGSUM2D, DLACPY, DSCAL, DTRMVT, PCHK1MAT,
+     $                   DGSUM2D, DLAMOV, DSCAL, DTRMVT, PCHK1MAT,
      $                   PDTREECOMB, PXERBLA
 *     ..
 *     .. External Functions ..
@@ -1128,10 +1127,10 @@
                IF( INTERLEAVE ) THEN
                   LDZG = LDV / 2
                ELSE
-                  CALL DLACPY( 'A', LTNM1, ANB, WORK( INHT+LIJP1-1 ),
+                  CALL DLAMOV( 'A', LTNM1, ANB, WORK( INHT+LIJP1-1 ),
      $                         LDV, WORK( INVT+LIJP1-1+ANB*LDV ), LDV )
 *
-                  CALL DLACPY( 'A', LTNM1, ANB, WORK( INV+LTLIP1-1 ),
+                  CALL DLAMOV( 'A', LTNM1, ANB, WORK( INV+LTLIP1-1 ),
      $                         LDV, WORK( INH+LTLIP1-1+ANB*LDV ), LDV )
                   LDZG = LDV
                END IF
