@@ -1,12 +1,10 @@
       SUBROUTINE PSDTTRS( TRANS, N, NRHS, DL, D, DU, JA, DESCA, B, IB,
      $                    DESCB, AF, LAF, WORK, LWORK, INFO )
 *
-*
-*
-*  -- ScaLAPACK routine (version 1.6) --
+*  -- ScaLAPACK routine (version 1.7) --
 *     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
 *     and University of California, Berkeley.
-*     November 15, 1997
+*     April 3, 2000
 *
 *     .. Scalar Arguments ..
       CHARACTER          TRANS
@@ -375,19 +373,14 @@
 *
 *  Code Developer: Andrew J. Cleary, University of Tennessee.
 *    Current address: Lawrence Livermore National Labs.
-*  This version released: May, 1997.
 *
 *  =====================================================================
 *
-*     ..
 *     .. Parameters ..
-      REAL               ONE, ZERO
-      PARAMETER          ( ONE = 1.0E+0 )
-      PARAMETER          ( ZERO = 0.0E+0 )
       INTEGER            INT_ONE
       PARAMETER          ( INT_ONE = 1 )
       INTEGER            DESCMULT, BIGNUM
-      PARAMETER          (DESCMULT = 100, BIGNUM = DESCMULT * DESCMULT)
+      PARAMETER          ( DESCMULT = 100, BIGNUM = DESCMULT*DESCMULT )
       INTEGER            BLOCK_CYCLIC_2D, CSRC_, CTXT_, DLEN_, DTYPE_,
      $                   LLD_, MB_, M_, NB_, N_, RSRC_
       PARAMETER          ( BLOCK_CYCLIC_2D = 1, DLEN_ = 9, DTYPE_ = 1,
@@ -398,26 +391,24 @@
       INTEGER            CSRC, FIRST_PROC, ICTXT, ICTXT_NEW, ICTXT_SAVE,
      $                   IDUM2, IDUM3, JA_NEW, LLDA, LLDB, MYCOL, MYROW,
      $                   MY_NUM_COLS, NB, NP, NPCOL, NPROW, NP_SAVE,
-     $                   ODD_SIZE, PART_OFFSET, PART_SIZE,
-     $                   RETURN_CODE, STORE_M_B, STORE_N_A, TEMP,
-     $                   WORK_SIZE_MIN
+     $                   ODD_SIZE, PART_OFFSET, PART_SIZE, RETURN_CODE,
+     $                   STORE_M_B, STORE_N_A, TEMP, WORK_SIZE_MIN
 *     ..
 *     .. Local Arrays ..
       INTEGER            DESCA_1XP( 7 ), DESCB_PX1( 7 ),
      $                   PARAM_CHECK( 15, 3 )
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           BLACS_GRIDINFO, DESC_CONVERT, GLOBCHK,
-     $                   PSDTTRSV, PXERBLA
+      EXTERNAL           BLACS_GRIDEXIT, BLACS_GRIDINFO, DESC_CONVERT,
+     $                   GLOBCHK, PSDTTRSV, PXERBLA, RESHAPE
 *     ..
 *     .. External Functions ..
       LOGICAL            LSAME
       INTEGER            NUMROC
-      REAL               SDOT
-      EXTERNAL           LSAME, NUMROC, SDOT
+      EXTERNAL           LSAME, NUMROC
 *     ..
 *     .. Intrinsic Functions ..
-      INTRINSIC          ICHAR, MIN, MOD
+      INTRINSIC          ICHAR, MOD
 *     ..
 *     .. Executable Statements ..
 *
@@ -432,45 +423,45 @@
       DESCB_PX1( 1 ) = 502
 *
       TEMP = DESCA( DTYPE_ )
-      IF( TEMP .EQ. 502 ) THEN
+      IF( TEMP.EQ.502 ) THEN
 *        Temporarily set the descriptor type to 1xP type
          DESCA( DTYPE_ ) = 501
-      ENDIF
+      END IF
 *
       CALL DESC_CONVERT( DESCA, DESCA_1XP, RETURN_CODE )
 *
       DESCA( DTYPE_ ) = TEMP
 *
-      IF( RETURN_CODE .NE. 0) THEN
-         INFO = -( 8*100 + 2 )
-      ENDIF
+      IF( RETURN_CODE.NE.0 ) THEN
+         INFO = -( 8*100+2 )
+      END IF
 *
       CALL DESC_CONVERT( DESCB, DESCB_PX1, RETURN_CODE )
 *
-      IF( RETURN_CODE .NE. 0) THEN
-         INFO = -( 11*100 + 2 )
-      ENDIF
+      IF( RETURN_CODE.NE.0 ) THEN
+         INFO = -( 11*100+2 )
+      END IF
 *
 *     Consistency checks for DESCA and DESCB.
 *
 *     Context must be the same
-      IF( DESCA_1XP( 2 ) .NE. DESCB_PX1( 2 ) ) THEN
-         INFO = -( 11*100 + 2 )
-      ENDIF
+      IF( DESCA_1XP( 2 ).NE.DESCB_PX1( 2 ) ) THEN
+         INFO = -( 11*100+2 )
+      END IF
 *
 *        These are alignment restrictions that may or may not be removed
 *        in future releases. -Andy Cleary, April 14, 1996.
 *
 *     Block sizes must be the same
-      IF( DESCA_1XP( 4 ) .NE. DESCB_PX1( 4 ) ) THEN
-         INFO = -( 11*100 + 4 )
-      ENDIF
+      IF( DESCA_1XP( 4 ).NE.DESCB_PX1( 4 ) ) THEN
+         INFO = -( 11*100+4 )
+      END IF
 *
 *     Source processor must be the same
 *
-      IF( DESCA_1XP( 5 ) .NE. DESCB_PX1( 5 ) ) THEN
-         INFO = -( 11*100 + 5 )
-      ENDIF
+      IF( DESCA_1XP( 5 ).NE.DESCB_PX1( 5 ) ) THEN
+         INFO = -( 11*100+5 )
+      END IF
 *
 *     Get values out of descriptor for use in code.
 *
@@ -486,109 +477,103 @@
 *
 *
       CALL BLACS_GRIDINFO( ICTXT, NPROW, NPCOL, MYROW, MYCOL )
-      NP = NPROW * NPCOL
+      NP = NPROW*NPCOL
 *
 *
 *
       IF( LSAME( TRANS, 'N' ) ) THEN
          IDUM2 = ICHAR( 'N' )
-      ELSE IF ( LSAME( TRANS, 'T' ) ) THEN
+      ELSE IF( LSAME( TRANS, 'T' ) ) THEN
          IDUM2 = ICHAR( 'T' )
-      ELSE IF ( LSAME( TRANS, 'C' ) ) THEN
+      ELSE IF( LSAME( TRANS, 'C' ) ) THEN
          IDUM2 = ICHAR( 'T' )
       ELSE
          INFO = -1
       END IF
 *
-      IF( LWORK .LT. -1) THEN
+      IF( LWORK.LT.-1 ) THEN
          INFO = -15
-      ELSE IF ( LWORK .EQ. -1 ) THEN
+      ELSE IF( LWORK.EQ.-1 ) THEN
          IDUM3 = -1
       ELSE
          IDUM3 = 1
-      ENDIF
+      END IF
 *
-      IF( N .LT. 0 ) THEN
+      IF( N.LT.0 ) THEN
          INFO = -2
-      ENDIF
+      END IF
 *
-      IF( N+JA-1 .GT. STORE_N_A ) THEN
-         INFO = -( 8*100 + 6 )
-      ENDIF
+      IF( N+JA-1.GT.STORE_N_A ) THEN
+         INFO = -( 8*100+6 )
+      END IF
 *
-      IF( N+IB-1 .GT. STORE_M_B ) THEN
-         INFO = -( 11*100 + 3 )
-      ENDIF
+      IF( N+IB-1.GT.STORE_M_B ) THEN
+         INFO = -( 11*100+3 )
+      END IF
 *
-      IF( LLDB .LT. NB ) THEN
-         INFO = -( 11*100 + 6 )
-      ENDIF
+      IF( LLDB.LT.NB ) THEN
+         INFO = -( 11*100+6 )
+      END IF
 *
-      IF( NRHS .LT. 0 ) THEN
+      IF( NRHS.LT.0 ) THEN
          INFO = -3
-      ENDIF
+      END IF
 *
 *     Current alignment restriction
 *
-      IF( JA .NE. IB) THEN
+      IF( JA.NE.IB ) THEN
          INFO = -7
-      ENDIF
+      END IF
 *
 *     Argument checking that is specific to Divide & Conquer routine
 *
-      IF( NPROW .NE. 1 ) THEN
+      IF( NPROW.NE.1 ) THEN
          INFO = -( 8*100+2 )
-      ENDIF
+      END IF
 *
-      IF( N .GT. NP*NB-MOD( JA-1, NB )) THEN
+      IF( N.GT.NP*NB-MOD( JA-1, NB ) ) THEN
          INFO = -( 2 )
-         CALL PXERBLA( ICTXT,
-     $      'PSDTTRS, D&C alg.: only 1 block per proc',
-     $      -INFO )
+         CALL PXERBLA( ICTXT, 'PSDTTRS, D&C alg.: only 1 block per proc'
+     $                 , -INFO )
          RETURN
-      ENDIF
+      END IF
 *
-      IF((JA+N-1.GT.NB) .AND. ( NB.LT.2*INT_ONE )) THEN
+      IF( ( JA+N-1.GT.NB ) .AND. ( NB.LT.2*INT_ONE ) ) THEN
          INFO = -( 8*100+4 )
-         CALL PXERBLA( ICTXT,
-     $      'PSDTTRS, D&C alg.: NB too small',
-     $      -INFO )
+         CALL PXERBLA( ICTXT, 'PSDTTRS, D&C alg.: NB too small', -INFO )
          RETURN
-      ENDIF
+      END IF
 *
 *
-      WORK_SIZE_MIN =
-     $           10*NPCOL+4*NRHS
+      WORK_SIZE_MIN = 10*NPCOL + 4*NRHS
 *
       WORK( 1 ) = WORK_SIZE_MIN
 *
-      IF( LWORK .LT. WORK_SIZE_MIN ) THEN
-         IF( LWORK .NE. -1 ) THEN
-         INFO = -15
-         CALL PXERBLA( ICTXT,
-     $      'PSDTTRS: worksize error',
-     $      -INFO )
-         ENDIF
+      IF( LWORK.LT.WORK_SIZE_MIN ) THEN
+         IF( LWORK.NE.-1 ) THEN
+            INFO = -15
+            CALL PXERBLA( ICTXT, 'PSDTTRS: worksize error', -INFO )
+         END IF
          RETURN
-      ENDIF
+      END IF
 *
 *     Pack params and positions into arrays for global consistency check
 *
-      PARAM_CHECK( 15, 1 ) = DESCB(5)
-      PARAM_CHECK( 14, 1 ) = DESCB(4)
-      PARAM_CHECK( 13, 1 ) = DESCB(3)
-      PARAM_CHECK( 12, 1 ) = DESCB(2)
-      PARAM_CHECK( 11, 1 ) = DESCB(1)
+      PARAM_CHECK( 15, 1 ) = DESCB( 5 )
+      PARAM_CHECK( 14, 1 ) = DESCB( 4 )
+      PARAM_CHECK( 13, 1 ) = DESCB( 3 )
+      PARAM_CHECK( 12, 1 ) = DESCB( 2 )
+      PARAM_CHECK( 11, 1 ) = DESCB( 1 )
       PARAM_CHECK( 10, 1 ) = IB
-      PARAM_CHECK(  9, 1 ) = DESCA(5)
-      PARAM_CHECK(  8, 1 ) = DESCA(4)
-      PARAM_CHECK(  7, 1 ) = DESCA(3)
-      PARAM_CHECK(  6, 1 ) = DESCA(1)
-      PARAM_CHECK(  5, 1 ) = JA
-      PARAM_CHECK(  4, 1 ) = NRHS
-      PARAM_CHECK(  3, 1 ) = N
-      PARAM_CHECK(  2, 1 ) = IDUM3
-      PARAM_CHECK(  1, 1 ) = IDUM2
+      PARAM_CHECK( 9, 1 ) = DESCA( 5 )
+      PARAM_CHECK( 8, 1 ) = DESCA( 4 )
+      PARAM_CHECK( 7, 1 ) = DESCA( 3 )
+      PARAM_CHECK( 6, 1 ) = DESCA( 1 )
+      PARAM_CHECK( 5, 1 ) = JA
+      PARAM_CHECK( 4, 1 ) = NRHS
+      PARAM_CHECK( 3, 1 ) = N
+      PARAM_CHECK( 2, 1 ) = IDUM3
+      PARAM_CHECK( 1, 1 ) = IDUM2
 *
       PARAM_CHECK( 15, 2 ) = 1105
       PARAM_CHECK( 14, 2 ) = 1104
@@ -596,15 +581,15 @@
       PARAM_CHECK( 12, 2 ) = 1102
       PARAM_CHECK( 11, 2 ) = 1101
       PARAM_CHECK( 10, 2 ) = 10
-      PARAM_CHECK(  9, 2 ) = 805
-      PARAM_CHECK(  8, 2 ) = 804
-      PARAM_CHECK(  7, 2 ) = 803
-      PARAM_CHECK(  6, 2 ) = 801
-      PARAM_CHECK(  5, 2 ) = 7
-      PARAM_CHECK(  4, 2 ) = 3
-      PARAM_CHECK(  3, 2 ) = 2
-      PARAM_CHECK(  2, 2 ) = 15
-      PARAM_CHECK(  1, 2 ) = 1
+      PARAM_CHECK( 9, 2 ) = 805
+      PARAM_CHECK( 8, 2 ) = 804
+      PARAM_CHECK( 7, 2 ) = 803
+      PARAM_CHECK( 6, 2 ) = 801
+      PARAM_CHECK( 5, 2 ) = 7
+      PARAM_CHECK( 4, 2 ) = 3
+      PARAM_CHECK( 3, 2 ) = 2
+      PARAM_CHECK( 2, 2 ) = 15
+      PARAM_CHECK( 1, 2 ) = 1
 *
 *     Want to find errors with MIN( ), so if no error, set it to a big
 *     number. If there already is an error, multiply by the the
@@ -615,20 +600,20 @@
       ELSE IF( INFO.LT.-DESCMULT ) THEN
          INFO = -INFO
       ELSE
-         INFO = -INFO * DESCMULT
+         INFO = -INFO*DESCMULT
       END IF
 *
 *     Check consistency across processors
 *
-      CALL GLOBCHK( ICTXT, 15, PARAM_CHECK, 15,
-     $              PARAM_CHECK( 1, 3 ), INFO )
+      CALL GLOBCHK( ICTXT, 15, PARAM_CHECK, 15, PARAM_CHECK( 1, 3 ),
+     $              INFO )
 *
 *     Prepare output: set info = 0 if no error, and divide by DESCMULT
 *     if error is not in a descriptor entry.
 *
       IF( INFO.EQ.BIGNUM ) THEN
          INFO = 0
-      ELSE IF( MOD( INFO, DESCMULT ) .EQ. 0 ) THEN
+      ELSE IF( MOD( INFO, DESCMULT ).EQ.0 ) THEN
          INFO = -INFO / DESCMULT
       ELSE
          INFO = -INFO
@@ -651,15 +636,15 @@
 *     Adjust addressing into matrix space to properly get into
 *        the beginning part of the relevant data
 *
-      PART_OFFSET = NB*( (JA-1)/(NPCOL*NB) )
+      PART_OFFSET = NB*( ( JA-1 ) / ( NPCOL*NB ) )
 *
-      IF ( (MYCOL-CSRC) .LT. (JA-PART_OFFSET-1)/NB ) THEN
+      IF( ( MYCOL-CSRC ).LT.( JA-PART_OFFSET-1 ) / NB ) THEN
          PART_OFFSET = PART_OFFSET + NB
-      ENDIF
+      END IF
 *
-      IF ( MYCOL .LT. CSRC ) THEN
+      IF( MYCOL.LT.CSRC ) THEN
          PART_OFFSET = PART_OFFSET - NB
-      ENDIF
+      END IF
 *
 *     Form a new BLACS grid (the "standard form" grid) with only procs
 *        holding part of the matrix, of size 1xNP where NP is adjusted,
@@ -667,7 +652,7 @@
 *
 *     First processor to hold part of the matrix:
 *
-      FIRST_PROC = MOD( ( JA-1 )/NB+CSRC, NPCOL )
+      FIRST_PROC = MOD( ( JA-1 ) / NB+CSRC, NPCOL )
 *
 *     Calculate new JA one while dropping off unused processors.
 *
@@ -676,12 +661,12 @@
 *     Save and compute new value of NP
 *
       NP_SAVE = NP
-      NP = ( JA_NEW+N-2 )/NB + 1
+      NP = ( JA_NEW+N-2 ) / NB + 1
 *
 *     Call utility routine that forms "standard-form" grid
 *
-      CALL RESHAPE( ICTXT, INT_ONE, ICTXT_NEW, INT_ONE,
-     $              FIRST_PROC, INT_ONE, NP )
+      CALL RESHAPE( ICTXT, INT_ONE, ICTXT_NEW, INT_ONE, FIRST_PROC,
+     $              INT_ONE, NP )
 *
 *     Use new context from standard grid as context.
 *
@@ -696,9 +681,9 @@
 *
 *     Drop out processors that do not have part of the matrix.
 *
-      IF( MYROW .LT. 0 ) THEN
-         GOTO 1234
-      ENDIF
+      IF( MYROW.LT.0 ) THEN
+         GO TO 20
+      END IF
 *
 *     ********************************
 *     Values reused throughout routine
@@ -713,17 +698,17 @@
 *
 *     Offset in columns to beginning of main partition in each proc
 *
-      IF ( MYCOL .EQ. 0 ) THEN
-        PART_OFFSET = PART_OFFSET+MOD( JA_NEW-1, PART_SIZE )
-        MY_NUM_COLS = MY_NUM_COLS - MOD(JA_NEW-1, PART_SIZE )
-      ENDIF
+      IF( MYCOL.EQ.0 ) THEN
+         PART_OFFSET = PART_OFFSET + MOD( JA_NEW-1, PART_SIZE )
+         MY_NUM_COLS = MY_NUM_COLS - MOD( JA_NEW-1, PART_SIZE )
+      END IF
 *
 *     Size of main (or odd) partition in each processor
 *
       ODD_SIZE = MY_NUM_COLS
-      IF ( MYCOL .LT. NP-1 ) THEN
+      IF( MYCOL.LT.NP-1 ) THEN
          ODD_SIZE = ODD_SIZE - INT_ONE
-      ENDIF
+      END IF
 *
 *
 *
@@ -747,11 +732,11 @@
      $                  DESCA_1XP, B, IB, DESCB_PX1, AF, LAF, WORK,
      $                  LWORK, INFO )
 *
-      ENDIF
+      END IF
 *
 *     Call backsolve routine
 *
-      IF(( LSAME( TRANS, 'C')).OR.( LSAME( TRANS, 'T'))) THEN
+      IF( ( LSAME( TRANS, 'C' ) ) .OR. ( LSAME( TRANS, 'T' ) ) ) THEN
 *
          CALL PSDTTRSV( 'L', 'T', N, NRHS, DL( PART_OFFSET+1 ),
      $                  D( PART_OFFSET+1 ), DU( PART_OFFSET+1 ), JA_NEW,
@@ -765,17 +750,17 @@
      $                  DESCA_1XP, B, IB, DESCB_PX1, AF, LAF, WORK,
      $                  LWORK, INFO )
 *
-      ENDIF
- 1000 CONTINUE
+      END IF
+   10 CONTINUE
 *
 *
 *     Free BLACS space used to hold standard-form grid.
 *
-      IF( ICTXT_SAVE .NE. ICTXT_NEW ) THEN
+      IF( ICTXT_SAVE.NE.ICTXT_NEW ) THEN
          CALL BLACS_GRIDEXIT( ICTXT_NEW )
-      ENDIF
+      END IF
 *
- 1234 CONTINUE
+   20 CONTINUE
 *
 *     Restore saved input parameters
 *
