@@ -250,7 +250,7 @@
      $                   IVCOL, IVROW, JJC1, JJC2, JJV, LDC, LDV, MPC2,
      $                   MPV, MYCOL, MYROW, NCC, NCV, NPCOL, NPROW,
      $                   NQC2, NQV, RDEST
-      REAL               TAULOC
+      REAL               TAULOC( 1 )
 *     ..
 *     .. External Subroutines ..
       EXTERNAL           BLACS_GRIDINFO, INFOG2L, PB_TOPGET, PBSTRNV,
@@ -369,7 +369,7 @@
 *
                      CALL SGEBS2D( ICTXT, 'Columnwise', ' ', 1, 1,
      $                             TAU( IIV ), 1 )
-                     TAULOC = TAU( IIV )
+                     TAULOC( 1 ) = TAU( IIV )
 *
                   ELSE
 *
@@ -378,7 +378,7 @@
 *
                   END IF
 *
-                  IF( TAULOC.NE.ZERO ) THEN
+                  IF( TAULOC( 1 ).NE.ZERO ) THEN
 *
 *                    w := sub( C )' * v
 *
@@ -401,9 +401,9 @@
 *                    sub( C ) := sub( C ) - v * w'
 *
                      IF( MYROW.EQ.ICROW1 )
-     $                  CALL SAXPY( NQC2, -TAULOC, WORK( IPW ),
+     $                  CALL SAXPY( NQC2, -TAULOC( 1 ), WORK( IPW ),
      $                              MAX( 1, NQC2 ), C( IOFFC1 ), LDC )
-                     CALL SGER( MPV, NQC2, -TAULOC, WORK, 1,
+                     CALL SGER( MPV, NQC2, -TAULOC( 1 ), WORK, 1,
      $                          WORK( IPW ), 1, C( IOFFC2 ), LDC )
                   END IF
 *
@@ -419,9 +419,9 @@
 *
                   IF( MYCOL.EQ.ICCOL2 ) THEN
 *
-                     TAULOC = TAU( JJV )
+                     TAULOC( 1 ) = TAU( JJV )
 *
-                     IF( TAULOC.NE.ZERO ) THEN
+                     IF( TAULOC( 1 ).NE.ZERO ) THEN
 *
 *                       w := sub( C )' * v
 *
@@ -444,11 +444,11 @@
 *                       sub( C ) := sub( C ) - v * w'
 *
                         IF( MYROW.EQ.ICROW1 )
-     $                     CALL SAXPY( NQC2, -TAULOC, WORK,
+     $                     CALL SAXPY( NQC2, -TAULOC( 1 ), WORK,
      $                                 MAX( 1, NQC2 ), C( IOFFC1 ),
      $                                 LDC )
-                        CALL SGER( MPV, NQC2, -TAULOC, V( IOFFV ), 1,
-     $                             WORK, 1, C( IOFFC2 ), LDC )
+                        CALL SGER( MPV, NQC2, -TAULOC( 1 ), V( IOFFV ),
+     $                             1, WORK, 1, C( IOFFC2 ), LDC )
                      END IF
 *
                   END IF
@@ -470,9 +470,9 @@
                      IPW = MPV+1
                      CALL SGERV2D( ICTXT, IPW, 1, WORK, IPW, MYROW,
      $                             IVCOL )
-                     TAULOC = WORK( IPW )
+                     TAULOC( 1 ) = WORK( IPW )
 *
-                     IF( TAULOC.NE.ZERO ) THEN
+                     IF( TAULOC( 1 ).NE.ZERO ) THEN
 *
 *                       w := sub( C )' * v
 *
@@ -495,10 +495,10 @@
 *                       sub( C ) := sub( C ) - v * w'
 *
                         IF( MYROW.EQ.ICROW1 )
-     $                     CALL SAXPY( NQC2, -TAULOC, WORK( IPW ),
+     $                     CALL SAXPY( NQC2, -TAULOC( 1 ), WORK( IPW ),
      $                                 MAX( 1, NQC2 ), C( IOFFC1 ),
      $                                 LDC )
-                        CALL SGER( MPV, NQC2, -TAULOC, WORK, 1,
+                        CALL SGER( MPV, NQC2, -TAULOC( 1 ), WORK, 1,
      $                             WORK( IPW ), 1, C( IOFFC2 ), LDC )
                      END IF
 *
@@ -529,7 +529,7 @@
 *
                   CALL SGEBS2D( ICTXT, 'Columnwise', ' ', 1, 1,
      $                          TAU( IIV ), 1 )
-                  TAULOC = TAU( IIV )
+                  TAULOC( 1 ) = TAU( IIV )
 *
                ELSE
 *
@@ -538,7 +538,7 @@
 *
                END IF
 *
-               IF( TAULOC.NE.ZERO ) THEN
+               IF( TAULOC( 1 ).NE.ZERO ) THEN
 *
 *                 w := sub( C )' * v
 *
@@ -561,10 +561,10 @@
 *                 sub( C ) := sub( C ) - v * w'
 *
                   IF( MYROW.EQ.ICROW1 )
-     $               CALL SAXPY( NQC2, -TAULOC, WORK( IPW ),
+     $               CALL SAXPY( NQC2, -TAULOC( 1 ), WORK( IPW ),
      $                           MAX( 1, NQC2 ), C( IOFFC1 ), LDC )
-                  CALL SGER( MPV, NQC2, -TAULOC, WORK, 1, WORK( IPW ),
-     $                       1, C( IOFFC2 ), LDC )
+                  CALL SGER( MPV, NQC2, -TAULOC( 1 ), WORK, 1,
+     $                       WORK( IPW ), 1, C( IOFFC2 ), LDC )
                END IF
 *
             ELSE
@@ -579,18 +579,18 @@
                   WORK( IPW ) = TAU( JJV )
                   CALL SGEBS2D( ICTXT, 'Rowwise', ROWBTOP, IPW, 1,
      $                          WORK, IPW )
-                  TAULOC = TAU( JJV )
+                  TAULOC( 1 ) = TAU( JJV )
 *
                ELSE
 *
                   IPW = MPV+1
                   CALL SGEBR2D( ICTXT, 'Rowwise', ROWBTOP, IPW, 1, WORK,
      $                          IPW, MYROW, IVCOL )
-                  TAULOC = WORK( IPW )
+                  TAULOC( 1 ) = WORK( IPW )
 *
                END IF
 *
-               IF( TAULOC.NE.ZERO ) THEN
+               IF( TAULOC( 1 ).NE.ZERO ) THEN
 *
 *                 w := sub( C )' * v
 *
@@ -613,10 +613,10 @@
 *                 sub( C ) := sub( C ) - v * w'
 *
                   IF( MYROW.EQ.ICROW1 )
-     $               CALL SAXPY( NQC2, -TAULOC, WORK( IPW ),
+     $               CALL SAXPY( NQC2, -TAULOC( 1 ), WORK( IPW ),
      $                           MAX( 1, NQC2 ), C( IOFFC1 ), LDC )
-                  CALL SGER( MPV, NQC2, -TAULOC, WORK, 1, WORK( IPW ),
-     $                       1, C( IOFFC2 ), LDC )
+                  CALL SGER( MPV, NQC2, -TAULOC( 1 ), WORK, 1,
+     $                       WORK( IPW ), 1, C( IOFFC2 ), LDC )
                END IF
 *
             END IF
@@ -645,9 +645,9 @@
 *
                   IF( MYROW.EQ.ICROW2 ) THEN
 *
-                     TAULOC = TAU( IIV )
+                     TAULOC( 1 ) = TAU( IIV )
 *
-                     IF( TAULOC.NE.ZERO ) THEN
+                     IF( TAULOC( 1 ).NE.ZERO ) THEN
 *
 *                       w := sub( C ) * v
 *
@@ -668,13 +668,13 @@
      $                               ICCOL2 )
 *
                         IF( MYCOL.EQ.ICCOL1 )
-     $                     CALL SAXPY( MPC2, -TAULOC, WORK, 1,
+     $                     CALL SAXPY( MPC2, -TAULOC( 1 ), WORK, 1,
      $                                 C( IOFFC1 ), 1 )
 *
 *                       sub( C ) := sub( C ) - w * v'
 *
                         IF( MPC2.GT.0 .AND. NQV.GT.0 )
-     $                     CALL SGER( MPC2, NQV, -TAULOC, WORK, 1,
+     $                     CALL SGER( MPC2, NQV, -TAULOC( 1 ), WORK, 1,
      $                                V( IOFFV ), LDV, C( IOFFC2 ),
      $                                LDC )
                      END IF
@@ -698,9 +698,9 @@
                      IPW = NQV+1
                      CALL SGERV2D( ICTXT, IPW, 1, WORK, IPW, IVROW,
      $                             MYCOL )
-                     TAULOC = WORK( IPW )
+                     TAULOC( 1 ) = WORK( IPW )
 *
-                     IF( TAULOC.NE.ZERO ) THEN
+                     IF( TAULOC( 1 ).NE.ZERO ) THEN
 *
 *                       w := sub( C ) * v
 *
@@ -719,13 +719,13 @@
      $                                WORK( IPW ), MAX( 1, MPC2 ),
      $                                RDEST, ICCOL2 )
                         IF( MYCOL.EQ.ICCOL1 )
-     $                     CALL SAXPY( MPC2, -TAULOC, WORK( IPW ), 1,
-     $                                 C( IOFFC1 ), 1 )
+     $                     CALL SAXPY( MPC2, -TAULOC( 1 ), WORK( IPW ),
+     $                                 1, C( IOFFC1 ), 1 )
 *
 *                       sub( C ) := sub( C ) - w * v'
 *
-                        CALL SGER( MPC2, NQV, -TAULOC, WORK( IPW ), 1,
-     $                             WORK, 1, C( IOFFC2 ), LDC )
+                        CALL SGER( MPC2, NQV, -TAULOC( 1 ), WORK( IPW ),
+     $                             1, WORK, 1, C( IOFFC2 ), LDC )
                      END IF
 *
                   END IF
@@ -750,7 +750,7 @@
 *
                      CALL SGEBS2D( ICTXT, 'Rowwise', ' ', 1, 1,
      $                             TAU( JJV ), 1 )
-                     TAULOC = TAU( JJV )
+                     TAULOC( 1 ) = TAU( JJV )
 *
                   ELSE
 *
@@ -759,7 +759,7 @@
 *
                   END IF
 *
-                  IF( TAULOC.NE.ZERO ) THEN
+                  IF( TAULOC( 1 ).NE.ZERO ) THEN
 *
 *                    w := sub( C ) * v
 *
@@ -778,12 +778,12 @@
      $                             WORK( IPW ), MAX( 1, MPC2 ), RDEST,
      $                             ICCOL2 )
                      IF( MYCOL.EQ.ICCOL1 )
-     $                  CALL SAXPY( MPC2, -TAULOC, WORK( IPW ), 1,
+     $                  CALL SAXPY( MPC2, -TAULOC( 1 ), WORK( IPW ), 1,
      $                              C( IOFFC1 ), 1 )
 *
 *                    sub( C ) := sub( C ) - w * v'
 *
-                     CALL SGER( MPC2, NQV, -TAULOC, WORK( IPW ), 1,
+                     CALL SGER( MPC2, NQV, -TAULOC( 1 ), WORK( IPW ), 1,
      $                          WORK, 1, C( IOFFC2 ), LDC )
                   END IF
 *
@@ -808,18 +808,18 @@
                   WORK( IPW ) = TAU( IIV )
                   CALL SGEBS2D( ICTXT, 'Columnwise', COLBTOP, IPW, 1,
      $                          WORK, IPW )
-                  TAULOC = TAU( IIV )
+                  TAULOC( 1 ) = TAU( IIV )
 *
                ELSE
 *
                   IPW = NQV+1
                   CALL SGEBR2D( ICTXT, 'Columnwise', COLBTOP, IPW, 1,
      $                          WORK, IPW, IVROW, MYCOL )
-                  TAULOC = WORK( IPW )
+                  TAULOC( 1 ) = WORK( IPW )
 *
                END IF
 *
-               IF( TAULOC.NE.ZERO ) THEN
+               IF( TAULOC( 1 ).NE.ZERO ) THEN
 *
 *                 w := sub( C ) * v
 *
@@ -839,13 +839,13 @@
      $                          WORK( IPW ), MAX( 1, MPC2 ), RDEST,
      $                          ICCOL2 )
                   IF( MYCOL.EQ.ICCOL1 )
-     $               CALL SAXPY( MPC2, -TAULOC, WORK( IPW ), 1,
+     $               CALL SAXPY( MPC2, -TAULOC( 1 ), WORK( IPW ), 1,
      $                           C( IOFFC1 ), 1 )
 *
 *                 sub( C ) := sub( C ) - w * v'
 *
-                  CALL SGER( MPC2, NQV, -TAULOC, WORK( IPW ), 1, WORK,
-     $                       1, C( IOFFC2 ), LDC )
+                  CALL SGER( MPC2, NQV, -TAULOC( 1 ), WORK( IPW ), 1,
+     $                       WORK, 1, C( IOFFC2 ), LDC )
                END IF
 *
             ELSE
@@ -864,7 +864,7 @@
 *
                   CALL SGEBS2D( ICTXT, 'Rowwise', ' ', 1, 1, TAU( JJV ),
      $                          1 )
-                  TAULOC = TAU( JJV )
+                  TAULOC( 1 ) = TAU( JJV )
 *
                ELSE
 *
@@ -873,7 +873,7 @@
 *
                END IF
 *
-               IF( TAULOC.NE.ZERO ) THEN
+               IF( TAULOC( 1 ).NE.ZERO ) THEN
 *
 *                 w := sub( C ) * v
 *
@@ -892,13 +892,13 @@
      $                          WORK( IPW ), MAX( 1, MPC2 ), RDEST,
      $                          ICCOL2 )
                   IF( MYCOL.EQ.ICCOL1 )
-     $               CALL SAXPY( MPC2, -TAULOC, WORK( IPW ), 1,
+     $               CALL SAXPY( MPC2, -TAULOC( 1 ), WORK( IPW ), 1,
      $                           C( IOFFC1 ), 1 )
 *
 *                 sub( C ) := sub( C ) - w * v'
 *
-                  CALL SGER( MPC2, NQV, -TAULOC, WORK( IPW ), 1, WORK,
-     $                       1, C( IOFFC2 ), LDC )
+                  CALL SGER( MPC2, NQV, -TAULOC( 1 ), WORK( IPW ), 1,
+     $                       WORK, 1, C( IOFFC2 ), LDC )
                END IF
 *
             END IF
