@@ -526,11 +526,11 @@
             MMAX( 1 ) = M
             MMIN( 1 ) = M
             IF( NPROCS.GT.1 )
-     $           CALL IGAMX2D( ICTXT, 'All', TOP, 1, 1, MMAX, 1, -1,
-     $                -1, -1, -1, -1 )
+     $         CALL IGAMX2D( ICTXT, 'All', TOP, 1, 1, MMAX( 1 ), 1, -1,
+     $              -1, -1, -1, -1 )
             IF( NPROCS.GT.1 )
-     $           CALL IGAMN2D( ICTXT, 'All', TOP, 1, 1, MMIN, 1, -1,
-     $                -1, -1, -1, -1 )
+     $         CALL IGAMN2D( ICTXT, 'All', TOP, 1, 1, MMIN( 1 ), 1, -1,
+     $              -1, -1, -1, -1 )
             IF( MMAX( 1 ).GT.MMIN( 1 ) ) THEN
                M = MMAX( 1 )
                IF( NPROCS.GT.1 )
