@@ -376,6 +376,7 @@
      $                   NB, NP, NPCOL, NPROW, NP_SAVE, ODD_SIZE,
      $                   PART_OFFSET, PART_SIZE, RETURN_CODE, STORE_N_A,
      $                   TEMP, WORK_SIZE_MIN, WORK_U
+      COMPLEX*16         DOTC
 *     ..
 *     .. Local Arrays ..
       INTEGER            DESCA_1XP( 7 ), PARAM_CHECK( 7, 3 )
@@ -385,13 +386,12 @@
      $                   DESC_CONVERT, GLOBCHK, PXERBLA, RESHAPE, ZAXPY,
      $                   ZGEMM, ZGERV2D, ZGESD2D, ZLAMOV, ZLATCPY,
      $                   ZPBTRF, ZPOTRF, ZSYRK, ZTBTRS, ZTRMM, ZTRRV2D,
-     $                   ZTRSD2D, ZTRSM, ZTRTRS
+     $                   ZTRSD2D, ZTRSM, ZTRTRS, ZZDOTC
 *     ..
 *     .. External Functions ..
       LOGICAL            LSAME
       INTEGER            NUMROC
-      COMPLEX*16         ZDOTC
-      EXTERNAL           LSAME, NUMROC, ZDOTC
+      EXTERNAL           LSAME, NUMROC
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC          ICHAR, MIN, MOD
@@ -741,8 +741,8 @@
 *
 *         Calculate the update block for previous proc, E_i = GL_i{GU_i}
 *
-          AF( ODD_SIZE+3 ) = -CONE *
-     $        ZDOTC( ODD_SIZE, AF( 1 ), 1, AF( WORK_U+1 ), 1 )
+          CALL ZZDOTC( ODD_SIZE, DOTC, AF( 1 ), 1, AF( WORK_U+1 ), 1 )
+          AF( ODD_SIZE+3 ) = -CONE * DOTC
 *
 *
 *         Initiate send of E_i to previous processor to overlap
