@@ -1,10 +1,9 @@
       SUBROUTINE PZHETTRD( UPLO, N, A, IA, JA, DESCA, D, E, TAU, WORK,
      $                     LWORK, INFO )
 *
-*  -- ScaLAPACK routine (version 1.7) --
-*     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
-*     and University of California, Berkeley.
-*     October 15, 1999
+*  -- ScaLAPACK routine (version 2.0.2) --
+*     Univ. of Tennessee, Univ. of California Berkeley, Univ. of Colorado Denver
+*     May 1 2012
 *
 *     .. Scalar Arguments ..
       CHARACTER          UPLO
@@ -445,7 +444,7 @@
       EXTERNAL           BLACS_GRIDINFO, CHK1MAT, DCOMBNRM2, DGEBR2D,
      $                   DGEBS2D, DGSUM2D, PCHK1MAT, PDTREECOMB,
      $                   PXERBLA, ZGEBR2D, ZGEBS2D, ZGEMM, ZGEMV,
-     $                   ZGERV2D, ZGESD2D, ZGSUM2D, ZLACPY, ZSCAL,
+     $                   ZGERV2D, ZGESD2D, ZGSUM2D, ZLAMOV, ZSCAL,
      $                   ZTRMVT
 *     ..
 *     .. External Functions ..
@@ -1133,10 +1132,10 @@
                IF( INTERLEAVE ) THEN
                   LDZG = LDV / 2
                ELSE
-                  CALL ZLACPY( 'A', LTNM1, ANB, WORK( INHT+LIJP1-1 ),
+                  CALL ZLAMOV( 'A', LTNM1, ANB, WORK( INHT+LIJP1-1 ),
      $                         LDV, WORK( INVT+LIJP1-1+ANB*LDV ), LDV )
 *
-                  CALL ZLACPY( 'A', LTNM1, ANB, WORK( INV+LTLIP1-1 ),
+                  CALL ZLAMOV( 'A', LTNM1, ANB, WORK( INV+LTLIP1-1 ),
      $                         LDV, WORK( INH+LTLIP1-1+ANB*LDV ), LDV )
                   LDZG = LDV
                END IF
