@@ -251,7 +251,7 @@
      $                   IVCOL, IVROW, JJC1, JJC2, JJV, LDC, LDV, MPC2,
      $                   MPV, MYCOL, MYROW, NCC, NCV, NPCOL, NPROW,
      $                   NQC2, NQV, RDEST
-      COMPLEX*16         TAULOC
+      COMPLEX*16         TAULOC( 1 )
 *     ..
 *     .. External Subroutines ..
       EXTERNAL           BLACS_GRIDINFO, INFOG2L, PB_TOPGET, PBZTRNV,
@@ -370,17 +370,17 @@
 *
                      CALL ZGEBS2D( ICTXT, 'Columnwise', ' ', 1, 1,
      $                             TAU( IIV ), 1 )
-                     TAULOC = DCONJG( TAU( IIV ) )
+                     TAULOC( 1 ) = DCONJG( TAU( IIV ) )
 *
                   ELSE
 *
                      CALL ZGEBR2D( ICTXT, 'Columnwise', ' ', 1, 1,
      $                             TAULOC, 1, IVROW, MYCOL )
-                     TAULOC = DCONJG( TAULOC )
+                     TAULOC( 1 ) = DCONJG( TAULOC( 1 ) )
 *
                   END IF
 *
-                  IF( TAULOC.NE.ZERO ) THEN
+                  IF( TAULOC( 1 ).NE.ZERO ) THEN
 *
 *                    w := sub( C )' * v
 *
@@ -403,9 +403,9 @@
 *                    sub( C ) := sub( C ) - v * w'
 *
                      IF( MYROW.EQ.ICROW1 )
-     $                  CALL ZAXPY( NQC2, -TAULOC, WORK( IPW ),
+     $                  CALL ZAXPY( NQC2, -TAULOC( 1 ), WORK( IPW ),
      $                              MAX( 1, NQC2 ), C( IOFFC1 ), LDC )
-                     CALL ZGERC( MPV, NQC2, -TAULOC, WORK, 1,
+                     CALL ZGERC( MPV, NQC2, -TAULOC( 1 ), WORK, 1,
      $                           WORK( IPW ), 1, C( IOFFC2 ), LDC )
                   END IF
 *
@@ -421,9 +421,9 @@
 *
                   IF( MYCOL.EQ.ICCOL2 ) THEN
 *
-                     TAULOC = DCONJG( TAU( JJV ) )
+                     TAULOC( 1 ) = DCONJG( TAU( JJV ) )
 *
-                     IF( TAULOC.NE.ZERO ) THEN
+                     IF( TAULOC( 1 ).NE.ZERO ) THEN
 *
 *                       w := sub( C )' * v
 *
@@ -446,11 +446,11 @@
 *                       sub( C ) := sub( C ) - v * w'
 *
                         IF( MYROW.EQ.ICROW1 )
-     $                     CALL ZAXPY( NQC2, -TAULOC, WORK,
+     $                     CALL ZAXPY( NQC2, -TAULOC( 1 ), WORK,
      $                                 MAX( 1, NQC2 ), C( IOFFC1 ),
      $                                 LDC )
-                        CALL ZGERC( MPV, NQC2, -TAULOC, V( IOFFV ), 1,
-     $                              WORK, 1, C( IOFFC2 ), LDC )
+                        CALL ZGERC( MPV, NQC2, -TAULOC( 1 ), V( IOFFV ),
+     $                              1, WORK, 1, C( IOFFC2 ), LDC )
                      END IF
 *
                   END IF
@@ -472,9 +472,9 @@
                      IPW = MPV+1
                      CALL ZGERV2D( ICTXT, IPW, 1, WORK, IPW, MYROW,
      $                             IVCOL )
-                     TAULOC = DCONJG( WORK( IPW ) )
+                     TAULOC( 1 ) = DCONJG( WORK( IPW ) )
 *
-                     IF( TAULOC.NE.ZERO ) THEN
+                     IF( TAULOC( 1 ).NE.ZERO ) THEN
 *
 *                       w := sub( C )' * v
 *
@@ -497,10 +497,10 @@
 *                       sub( C ) := sub( C ) - v * w'
 *
                         IF( MYROW.EQ.ICROW1 )
-     $                     CALL ZAXPY( NQC2, -TAULOC, WORK( IPW ),
+     $                     CALL ZAXPY( NQC2, -TAULOC( 1 ), WORK( IPW ),
      $                                 MAX( 1, NQC2 ), C( IOFFC1 ),
      $                                 LDC )
-                        CALL ZGERC( MPV, NQC2, -TAULOC, WORK, 1,
+                        CALL ZGERC( MPV, NQC2, -TAULOC( 1 ), WORK, 1,
      $                              WORK( IPW ), 1, C( IOFFC2 ), LDC )
                      END IF
 *
@@ -531,17 +531,17 @@
 *
                   CALL ZGEBS2D( ICTXT, 'Columnwise', ' ', 1, 1,
      $                          TAU( IIV ), 1 )
-                  TAULOC = DCONJG( TAU( IIV ) )
+                  TAULOC( 1 ) = DCONJG( TAU( IIV ) )
 *
                ELSE
 *
                   CALL ZGEBR2D( ICTXT, 'Columnwise', ' ', 1, 1, TAULOC,
      $                          1, IVROW, MYCOL )
-                  TAULOC = DCONJG( TAULOC )
+                  TAULOC( 1 ) = DCONJG( TAULOC( 1 ) )
 *
                END IF
 *
-               IF( TAULOC.NE.ZERO ) THEN
+               IF( TAULOC( 1 ).NE.ZERO ) THEN
 *
 *                 w := sub( C )' * v
 *
@@ -564,10 +564,10 @@
 *                 sub( C ) := sub( C ) - v * w'
 *
                   IF( MYROW.EQ.ICROW1 )
-     $               CALL ZAXPY( NQC2, -TAULOC, WORK( IPW ),
+     $               CALL ZAXPY( NQC2, -TAULOC( 1 ), WORK( IPW ),
      $                           MAX( 1, NQC2 ), C( IOFFC1 ), LDC )
-                  CALL ZGERC( MPV, NQC2, -TAULOC, WORK, 1, WORK( IPW ),
-     $                        1, C( IOFFC2 ), LDC )
+                  CALL ZGERC( MPV, NQC2, -TAULOC( 1 ), WORK, 1,
+     $                        WORK( IPW ), 1, C( IOFFC2 ), LDC )
                END IF
 *
             ELSE
@@ -582,18 +582,18 @@
                   WORK( IPW ) = TAU( JJV )
                   CALL ZGEBS2D( ICTXT, 'Rowwise', ROWBTOP, IPW, 1,
      $                          WORK, IPW )
-                  TAULOC = DCONJG( TAU( JJV ) )
+                  TAULOC( 1 ) = DCONJG( TAU( JJV ) )
 *
                ELSE
 *
                   IPW = MPV+1
                   CALL ZGEBR2D( ICTXT, 'Rowwise', ROWBTOP, IPW, 1, WORK,
      $                          IPW, MYROW, IVCOL )
-                  TAULOC = DCONJG( WORK( IPW ) )
+                  TAULOC( 1 ) = DCONJG( WORK( IPW ) )
 *
                END IF
 *
-               IF( TAULOC.NE.ZERO ) THEN
+               IF( TAULOC( 1 ).NE.ZERO ) THEN
 *
 *                 w := sub( C )' * v
 *
@@ -616,10 +616,10 @@
 *                 sub( C ) := sub( C ) - v * w'
 *
                   IF( MYROW.EQ.ICROW1 )
-     $               CALL ZAXPY( NQC2, -TAULOC, WORK( IPW ),
+     $               CALL ZAXPY( NQC2, -TAULOC( 1 ), WORK( IPW ),
      $                           MAX( 1, NQC2 ), C( IOFFC1 ), LDC )
-                  CALL ZGERC( MPV, NQC2, -TAULOC, WORK, 1, WORK( IPW ),
-     $                        1, C( IOFFC2 ), LDC )
+                  CALL ZGERC( MPV, NQC2, -TAULOC( 1 ), WORK, 1,
+     $                        WORK( IPW ), 1, C( IOFFC2 ), LDC )
                END IF
 *
             END IF
@@ -648,9 +648,9 @@
 *
                   IF( MYROW.EQ.ICROW2 ) THEN
 *
-                     TAULOC = DCONJG( TAU( IIV ) )
+                     TAULOC( 1 ) = DCONJG( TAU( IIV ) )
 *
-                     IF( TAULOC.NE.ZERO ) THEN
+                     IF( TAULOC( 1 ).NE.ZERO ) THEN
 *
 *                       w := sub( C ) * v
 *
@@ -671,12 +671,12 @@
      $                               ICCOL2 )
 *
                         IF( MYCOL.EQ.ICCOL1 )
-     $                     CALL ZAXPY( MPC2, -TAULOC, WORK, 1,
+     $                     CALL ZAXPY( MPC2, -TAULOC( 1 ), WORK, 1,
      $                                 C( IOFFC1 ), 1 )
 *
 *                       sub( C ) := sub( C ) - w * v'
 *
-                        CALL ZGERC( MPC2, NQV, -TAULOC, WORK, 1,
+                        CALL ZGERC( MPC2, NQV, -TAULOC( 1 ), WORK, 1,
      $                              V( IOFFV ), LDV, C( IOFFC2 ), LDC )
                      END IF
 *
@@ -699,9 +699,9 @@
                      IPW = NQV+1
                      CALL ZGERV2D( ICTXT, IPW, 1, WORK, IPW, IVROW,
      $                             MYCOL )
-                     TAULOC = DCONJG( WORK( IPW ) )
+                     TAULOC( 1 ) = DCONJG( WORK( IPW ) )
 *
-                     IF( TAULOC.NE.ZERO ) THEN
+                     IF( TAULOC( 1 ).NE.ZERO ) THEN
 *
 *                       w := sub( C ) * v
 *
@@ -720,13 +720,14 @@
      $                                WORK( IPW ), MAX( 1, MPC2 ),
      $                                RDEST, ICCOL2 )
                         IF( MYCOL.EQ.ICCOL1 )
-     $                     CALL ZAXPY( MPC2, -TAULOC, WORK( IPW ), 1,
-     $                                 C( IOFFC1 ), 1 )
+     $                     CALL ZAXPY( MPC2, -TAULOC( 1 ), WORK( IPW ),
+     $                                 1, C( IOFFC1 ), 1 )
 *
 *                       sub( C ) := sub( C ) - w * v'
 *
-                        CALL ZGERC( MPC2, NQV, -TAULOC, WORK( IPW ), 1,
-     $                              WORK, 1, C( IOFFC2 ), LDC )
+                        CALL ZGERC( MPC2, NQV, -TAULOC( 1 ),
+     $                              WORK( IPW ), 1, WORK, 1,
+     $                              C( IOFFC2 ), LDC )
                      END IF
 *
                   END IF
@@ -751,17 +752,17 @@
 *
                      CALL ZGEBS2D( ICTXT, 'Rowwise', ' ', 1, 1,
      $                             TAU( JJV ), 1 )
-                     TAULOC = DCONJG( TAU( JJV ) )
+                     TAULOC( 1 ) = DCONJG( TAU( JJV ) )
 *
                   ELSE
 *
                      CALL ZGEBR2D( ICTXT, 'Rowwise', ' ', 1, 1, TAULOC,
      $                             1, MYROW, IVCOL )
-                     TAULOC = DCONJG( TAULOC )
+                     TAULOC( 1 ) = DCONJG( TAULOC( 1 ) )
 *
                   END IF
 *
-                  IF( TAULOC.NE.ZERO ) THEN
+                  IF( TAULOC( 1 ).NE.ZERO ) THEN
 *
 *                    w := sub( C ) * v
 *
@@ -780,13 +781,13 @@
      $                             WORK( IPW ), MAX( 1, MPC2 ), RDEST,
      $                             ICCOL2 )
                      IF( MYCOL.EQ.ICCOL1 )
-     $                  CALL ZAXPY( MPC2, -TAULOC, WORK( IPW ), 1,
+     $                  CALL ZAXPY( MPC2, -TAULOC( 1 ), WORK( IPW ), 1,
      $                              C( IOFFC1 ), 1 )
 *
 *                    sub( C ) := sub( C ) - w * v'
 *
-                     CALL ZGERC( MPC2, NQV, -TAULOC, WORK( IPW ), 1,
-     $                           WORK, 1, C( IOFFC2 ), LDC )
+                     CALL ZGERC( MPC2, NQV, -TAULOC( 1 ), WORK( IPW ),
+     $                           1, WORK, 1, C( IOFFC2 ), LDC )
                   END IF
 *
                END IF
@@ -810,18 +811,18 @@
                   WORK( IPW ) = TAU( IIV )
                   CALL ZGEBS2D( ICTXT, 'Columnwise', COLBTOP, IPW, 1,
      $                          WORK, IPW )
-                  TAULOC = DCONJG( TAU( IIV ) )
+                  TAULOC( 1 ) = DCONJG( TAU( IIV ) )
 *
                ELSE
 *
                   IPW = NQV+1
                   CALL ZGEBR2D( ICTXT, 'Columnwise', COLBTOP, IPW, 1,
      $                          WORK, IPW, IVROW, MYCOL )
-                  TAULOC = DCONJG( WORK( IPW ) )
+                  TAULOC( 1 ) = DCONJG( WORK( IPW ) )
 *
                END IF
 *
-               IF( TAULOC.NE.ZERO ) THEN
+               IF( TAULOC( 1 ).NE.ZERO ) THEN
 *
 *                 w := sub( C ) * v
 *
@@ -841,13 +842,13 @@
      $                          WORK( IPW ), MAX( 1, MPC2 ), RDEST,
      $                          ICCOL2 )
                   IF( MYCOL.EQ.ICCOL1 )
-     $               CALL ZAXPY( MPC2, -TAULOC, WORK( IPW ), 1,
+     $               CALL ZAXPY( MPC2, -TAULOC( 1 ), WORK( IPW ), 1,
      $                           C( IOFFC1 ), 1 )
 *
 *                 sub( C ) := sub( C ) - w * v'
 *
-                  CALL ZGERC( MPC2, NQV, -TAULOC, WORK( IPW ), 1, WORK,
-     $                        1, C( IOFFC2 ), LDC )
+                  CALL ZGERC( MPC2, NQV, -TAULOC( 1 ), WORK( IPW ), 1,
+     $                        WORK, 1, C( IOFFC2 ), LDC )
                END IF
 *
             ELSE
@@ -866,17 +867,17 @@
 *
                   CALL ZGEBS2D( ICTXT, 'Rowwise', ' ', 1, 1, TAU( JJV ),
      $                          1 )
-                  TAULOC = DCONJG( TAU( JJV ) )
+                  TAULOC( 1 ) = DCONJG( TAU( JJV ) )
 *
                ELSE
 *
                   CALL ZGEBR2D( ICTXT, 'Rowwise', ' ', 1, 1, TAULOC, 1,
      $                          MYROW, IVCOL )
-                  TAULOC = DCONJG( TAULOC )
+                  TAULOC( 1 ) = DCONJG( TAULOC( 1 ) )
 *
                END IF
 *
-               IF( TAULOC.NE.ZERO ) THEN
+               IF( TAULOC( 1 ).NE.ZERO ) THEN
 *
 *                 w := sub( C ) * v
 *
@@ -895,13 +896,13 @@
      $                          WORK( IPW ), MAX( 1, MPC2 ), RDEST,
      $                          ICCOL2 )
                   IF( MYCOL.EQ.ICCOL1 )
-     $               CALL ZAXPY( MPC2, -TAULOC, WORK( IPW ), 1,
+     $               CALL ZAXPY( MPC2, -TAULOC( 1 ), WORK( IPW ), 1,
      $                           C( IOFFC1 ), 1 )
 *
 *                 sub( C ) := sub( C ) - w * v'
 *
-                  CALL ZGERC( MPC2, NQV, -TAULOC, WORK( IPW ), 1, WORK,
-     $                        1, C( IOFFC2 ), LDC )
+                  CALL ZGERC( MPC2, NQV, -TAULOC( 1 ), WORK( IPW ), 1,
+     $                        WORK, 1, C( IOFFC2 ), LDC )
                END IF
 *
             END IF
