@@ -131,15 +131,15 @@
       INTEGER            IACOL, IAROW, ICURR, IDIAG, IIA, IOFFA, JJA,
      $                   LDA, MYCOL, MYROW, NA, NPCOL, NPROW
       DOUBLE PRECISION   AII
+      COMPLEX*16         DOTC
 *     ..
 *     .. External Subroutines ..
       EXTERNAL           BLACS_GRIDINFO, INFOG2L, ZDSCAL, ZGEMV,
-     $                   ZLACGV
+     $                   ZLACGV, ZZDOTC
 *     ..
 *     .. External Functions ..
       LOGICAL            LSAME
-      COMPLEX*16         ZDOTC
-      EXTERNAL           LSAME, ZDOTC
+      EXTERNAL           LSAME
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC          DCMPLX, DBLE
@@ -170,8 +170,8 @@
             DO 10 NA = N-1, 1, -1
                AII = A( IDIAG )
                ICURR = IDIAG + LDA
-               A( IDIAG ) = AII*AII + DBLE( ZDOTC( NA, A( ICURR ), LDA,
-     $                                           A( ICURR ), LDA ) )
+               CALL ZZDOTC( NA, DOTC, A( ICURR ), LDA, A( ICURR ), LDA )
+               A( IDIAG ) = AII*AII + DBLE( DOTC )
                CALL ZLACGV( NA, A( ICURR ), LDA )
                CALL ZGEMV( 'No transpose', N-NA-1, NA, ONE,
      $                     A( IOFFA+LDA ), LDA, A( ICURR ), LDA,
