@@ -152,19 +152,19 @@
      $                   IOFFA, IROFF, J, JJA, LDA, MYCOL, MYROW,
      $                   NPCOL, NPROW
       DOUBLE PRECISION   AJJ
+      COMPLEX*16         DOT
 *     ..
 *     .. External Subroutines ..
       EXTERNAL           BLACS_ABORT, BLACS_GRIDINFO, CHK1MAT, IGEBR2D,
      $                   IGEBS2D, INFOG2L, PB_TOPGET, PXERBLA, ZGEMV,
-     $                   ZLACGV, ZDSCAL
+     $                   ZLACGV, ZDSCAL, ZZDOTC
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC          DBLE, MOD, SQRT
 *     ..
 *     .. External Functions ..
       LOGICAL            LSAME
-      COMPLEX*16         ZDOTC
-      EXTERNAL           LSAME, ZDOTC
+      EXTERNAL           LSAME
 *     ..
 *     .. Executable Statements ..
 *
@@ -233,8 +233,8 @@
 *
 *                 Compute U(J,J) and test for non-positive-definiteness.
 *
-                  AJJ = DBLE( A( IDIAG ) ) -
-     $                  ZDOTC( J-JA, A( IOFFA ), 1, A( IOFFA ), 1 )
+                  CALL ZZDOTC( J-JA, DOT, A( IOFFA ), 1, A( IOFFA ), 1 )
+                  AJJ = DBLE( A( IDIAG ) - DOT )
                   IF( AJJ.LE.ZERO ) THEN
                      A( IDIAG ) = AJJ
                      INFO = J - JA + 1
@@ -299,8 +299,9 @@
 *
 *                 Compute L(J,J) and test for non-positive-definiteness.
 *
-                  AJJ = DBLE( A( IDIAG ) ) -
-     $                  ZDOTC( J-JA, A( IOFFA ), LDA, A( IOFFA ), LDA )
+                  CALL ZZDOTC( J-JA, DOT, A( IOFFA ), LDA, A( IOFFA ),
+     $                         LDA )
+                  AJJ = DBLE( A( IDIAG ) - DOT )
                   IF ( AJJ.LE.ZERO ) THEN
                      A( IDIAG ) = AJJ
                      INFO = J - JA + 1
