@@ -7,7 +7,7 @@
      $                        LRWORK, LWORK1, IWORK, LIWORK, RESULT,
      $                        TSTNRM, QTQNRM, NOUT )
 *
-*  -- ScaLAPACK routine (version 1.6) --
+*  -- ScaLAPACK routine (version 1.7) --
 *     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
 *     and University of California, Berkeley.
 *     November 15, 1997
@@ -223,7 +223,7 @@
      $                   RSIZECHK, RSIZEHEEVX, RSIZEQTQ, RSIZESUBTST,
      $                   RSIZETST, SIZEHEEVX, SIZEMQRLEFT, SIZEMQRRIGHT,
      $                   SIZEQRF, SIZESUBTST, SIZETMS, SIZETST, VALSIZE,
-     $                   VECSIZE
+     $                   VECSIZE, SIZEHEEVD, RSIZEHEEVD, ISIZEHEEVD
       REAL               EPS, EPSNORMA, ERROR, MAXERROR, MAXVU,
      $                   MINERROR, MINVL, NORMWIN, OLDVL, OLDVU, ORFAC,
      $                   SAFMIN
@@ -255,6 +255,7 @@
       CALL PCLASIZESEP( DESCA, IPREPAD, IPOSTPAD, SIZEMQRLEFT,
      $                  SIZEMQRRIGHT, SIZEQRF, SIZETMS, RSIZEQTQ,
      $                  RSIZECHK, SIZEHEEVX, RSIZEHEEVX, ISIZEHEEVX,
+     $                  SIZEHEEVD, RSIZEHEEVD, ISIZEHEEVD,
      $                  SIZESUBTST, RSIZESUBTST, ISIZESUBTST, SIZETST,
      $                  RSIZETST, ISIZETST )
 *
