@@ -346,7 +346,7 @@
       INTEGER            PARAM_CHECK( 17, 3 )
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           BLACS_GRIDINFO, PXERBLA
+      EXTERNAL           BLACS_GRIDINFO, PXERBLA, RESHAPE
 *     ..
 *     .. External Functions ..
       LOGICAL            LSAME
