@@ -1,10 +1,9 @@
       SUBROUTINE CLATMS( M, N, DIST, ISEED, SYM, D, MODE, COND, DMAX,
      $                   KL, KU, PACK, A, LDA, WORK, INFO )
 *
-*  -- LAPACK test routine (version 3.0) --
-*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
-*     Courant Institute, Argonne National Lab, and Rice University
-*     September 30, 1994
+*  -- LAPACK test routine (version 3.1) --
+*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..
+*     November 2006
 *
 *     .. Scalar Arguments ..
       CHARACTER          DIST, PACK, SYM
@@ -377,6 +376,9 @@
       UUB = MIN( KU, N-1 )
       MR = MIN( M, N+LLB )
       NC = MIN( N, M+UUB )
+      IROW = 1
+      ICOL = 1
+      CSYM = .FALSE.
 *
       IF( IPACK.EQ.5 .OR. IPACK.EQ.6 ) THEN
          MINLDA = UUB + 1
